<?php
/*
*
* @name age_ranges_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: age_ranges_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class age_ranges_block extends blockgets_block
{
	function init()
	{
		global $db, $template, $user;

		$this->tpl_name = 'age_ranges_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}

		$ranges = array();
		$total_birthdays = $total_age = 0;

		//Create ranges
		$age_start = $data['age_start'];
		while($age_start < ($data['age_end']))
		{
			$age_end = $age_start + $data['age_interval'];
			$ranges[] = array(
				'range'		=> $age_start . (($age_end > $data['age_end']) ? '+' : '-' . $age_end),
				'users'		=> 0,
				'ismine'	=> false,
			);

			$age_start = $age_start + $data['age_interval'] + 1;
		}

		// Load birthdays from users table.
		$now = getdate(time() + $user->timezone + $user->dst - date('Z'));

		$sql = 'SELECT user_id, user_birthday
			FROM ' . USERS_TABLE . "
			WHERE user_birthday <> ''
			AND user_type <> " . USER_IGNORE;
		$result = $db->sql_query($sql);

		while($row = $db->sql_fetchrow($result))
		{
			if($year = (int) substr($row['user_birthday'], -4))
			{
				$age = $now['year'] - $year;
				$range = ceil(($age - $data['age_start'] - $data['age_interval']) / $data['age_interval']);

				// Exclude users out of range
				if($age >= $data['age_start'] && $age <= $data['age_end'])
				{
					if($row['user_id'] == $user->data['user_id'])
					{
						$ranges[$range]['ismine'] = true;
					}

					$ranges[$range]['users']++;
					$total_birthdays++;
					$total_age += $age;
				}
			}
		}				
		$db->sql_freeresult($result);

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('rangerow');
		
		// Return if no birthdays
		if(!$total_birthdays)
		{
			return false;
		}

		foreach($ranges as $range)
		{
			$template->assign_block_vars('rangerow', array(
				'RANGE'		=> $range['range'],
				'USERS'		=> $range['users'] . ' (' . (($range['users']*100) / $total_birthdays) . '%)',
				'ISMINE'	=> $range['ismine'],
			));
		}

		$template->assign_vars(array(
			'S_AGE_COUNTS'		=> $total_birthdays,
			'S_AGE_AV'			=> $user->lang('AGE_AV_COUNT', ($total_age / $total_birthdays)),
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$this->display_vars = array(
			'age_start'		=> array('lang' => 'AGE_START',		'validate' => 'int:1:50',	'type' => 'text:4:2',	'default' => 1),
			'age_end'		=> array('lang' => 'AGE_END',		'validate' => 'int:1:120',	'type' => 'text:4:3',	'default' => 100),
			'age_interval'	=> array('lang' => 'AGE_INTERVAL',	'validate' => 'int:10:40',	'type' => 'text:4:2',	'default' => 10),
		);

		return true;
	}
}

?>
