<?php
/*
*
* @name announcements_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: announcements_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class announcements_block extends blockgets_block
{
	function init()
	{
		global $phpbb_root_path, $template, $db, $auth, $config, $user, $phpEx;

		$this->tpl_name = 'announcements_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}

		$attachments = $attach_list = $rowset = $update_count = array();
		$sql_where = $bbcode_bitfield = '';

		if(!empty($data['forums']))
		{
			foreach($data['forums'] as $id => $forum_id)
			{
				if(!$auth->acl_get('f_read', $forum_id))
				{
					unset($data['forums'][$id]);
				}
			}
		}

		if(!empty($data['forums']))
		{
			$sql_where = ' AND ((t.topic_type = ' .  POST_ANNOUNCE . ' AND ' . $db->sql_in_set('t.forum_id', $data['forums']) . ')' . 
				(($data['show_globals']) ? ' OR t.topic_type = ' .  POST_GLOBAL : '') . ')';

		}
		else if($data['show_globals'])
		{
			$sql_where = ' AND t.topic_type = ' .  POST_GLOBAL;
		}

		if(!$sql_where)
		{
			return true;
		}

		$sql = 'SELECT t.forum_id, t.topic_id, t.topic_time, t.topic_replies, t.topic_views, t.poll_start,
			p.post_id, p.post_subject, p.post_attachment, p.post_approved, p.post_reported, p.post_username, p.post_text, p.bbcode_uid, p.bbcode_bitfield, p.enable_smilies,
			u.user_id, u.username, u.user_colour
			FROM ' . TOPICS_TABLE . ' t
			LEFT JOIN ' . POSTS_TABLE . ' p ON (t.topic_first_post_id = p.post_id)
			LEFT JOIN ' . USERS_TABLE . ' u ON (u.user_id = t.topic_poster)
			WHERE t.topic_status <> ' . ITEM_MOVED . " AND t.topic_approved = 1
			$sql_where
			ORDER BY t.topic_time DESC";

		$result = $db->sql_query_limit($sql, (int)$data['max_number']);

		while($row = $db->sql_fetchrow($result))
		{
			// Does post have an attachment? If so, add it to the list
			if($row['post_attachment'] && $config['allow_attachments'])
			{
				if($auth->acl_get('u_download') && $auth->acl_get('f_download', $row['forum_id']))
				{
					$attach_list[] = (int) $row['post_id'];
				}
			}

			$rowset[] = $row;

			// Define the global bbcode bitfield, will be used to load bbcodes
			$bbcode_bitfield = $bbcode_bitfield | base64_decode($row['bbcode_bitfield']);
		}
		$db->sql_freeresult($result);

		// Pull attachment data
		if(sizeof($attach_list))
		{
			$sql = 'SELECT *
				FROM ' . ATTACHMENTS_TABLE . '
				WHERE ' . $db->sql_in_set('post_msg_id', $attach_list) . '
					AND in_message = 0
				ORDER BY filetime DESC, post_msg_id ASC';
			$result = $db->sql_query($sql);

			while ($row = $db->sql_fetchrow($result))
			{
				$attachments[$row['post_msg_id']][] = $row;
			}
			$db->sql_freeresult($result);
		}

		// Instantiate BBCode if need be
		if ($bbcode_bitfield !== '')
		{
			$bbcode = new bbcode(base64_encode($bbcode_bitfield));
		}

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('ann_row');

		foreach($rowset as $row)
		{
			// Parse the message and subject
			$message = censor_text($row['post_text']);

			// Second parse bbcode here
			if ($row['bbcode_bitfield'])
			{
				$bbcode->bbcode_second_pass($message, $row['bbcode_uid'], $row['bbcode_bitfield']);
			}

			$message = bbcode_nl2br($message);
			$message = smiley_text($message);

			if (!empty($attachments[$row['post_id']]))
			{
				parse_attachments($row['forum_id'], $message, $attachments[$row['post_id']], $update_count);
			}

			$message = html_truncate($message, $data['max_size'], '...');

			$template->assign_block_vars('ann_row', array(
				'ID'					=> $row['topic_id'],
				'TITLE'					=> censor_text($row['post_subject']),
				'TIME'					=> $user->format_date($row['topic_time']),
				'S_HAS_ATTACHMENTS'		=> (!empty($attachments[$row['post_id']])) ? true : false,
				'TEXT'					=> $message,
				'POST_AUTHOR_FULL'		=> get_username_string('full', $row['user_id'], $row['username'], $row['user_colour'], $row['post_username']),
				'U_VIEW_TOPIC'			=> append_sid("{$phpbb_root_path}viewtopic.$phpEx", "t={$row['topic_id']}"),
			));	

			// Display not already displayed Attachments for this post, we already parsed them. ;)
			if (!empty($attachments[$row['post_id']]))
			{
				foreach ($attachments[$row['post_id']] as $attachment)
				{
					$template->assign_block_vars('ann_row.attachment', array(
						'DISPLAY_ATTACHMENT'	=> $attachment
					));
				}
			}

			unset($rowset[$row['post_id']]);
			unset($attachments[$row['post_id']]);
		}
		unset($rowset, $user_cache);

		$template->assign_vars(array(
			'S_SHORT_MODE'		=> $this->config['autofit'],
			'S_ANNS_COLLAPSE'	=> $data['collapse'],
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				if($submit)
				{
					$new['forums'] = request_var('forums', array(0));
				}
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
		return true;
	}

	function get_config()
	{
		$this->display_vars = array(
			'max_number'	=> array('lang' => 'ANN_MAX_NUMBER',	'validate' => 'int:1',	'type' => 'text:4:3',	'default' => 4),
			'max_size'		=> array('lang' => 'ANN_MAX_SIZE',		'validate' => 'int:1',	'type' => 'text:4:3',	'default' => 255),
			'forums'		=> array('lang' => 'FORUMS',			'type' => 'custom',		'function' => 'blg_forums_select', 'params' => array('forums', '{CONFIG_VALUE}', 1)),
			'show_globals'	=> array('lang' => 'ANN_SHOW_GLOBALS',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 0),
			'collapse'		=> array('lang' => 'ANN_COLLAPSE',		'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 0),
		);

		return true;
	}
}

?>
