<?php
/*
*
* @name attachments_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: attachments_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class attachments_block extends blockgets_block
{
	var $preview_path = 'blockgets/images/attach/';

	function init()
	{
		global $phpbb_root_path, $template, $db, $auth, $user, $phpEx;

		$this->tpl_name = 'attachments_block';

		if(($data = $this->unserialize()) === false || !$auth->acl_get('u_download'))
		{
			return false;
		}

		$sql = 'SELECT a.*, t.forum_id
			FROM ' . ATTACHMENTS_TABLE . ' a
			LEFT JOIN ' . TOPICS_TABLE . ' t ON(t.topic_id = a.topic_id)
			WHERE a.is_orphan = 0
			AND a.filesize > 0';

		if($data['filename'])
		{
			$sql .= " AND a.real_filename = '" . $db->sql_escape($data['filename']) . "'";
		}
		else
		{
			if(!empty($data['extension']))
			{
				// Get and trim extensions
				$extensions = explode(',', $data['extension']);
				$extensions = array_map('trim', $extensions);
				
				$sql .= ' AND ' . $db->sql_in_set('a.extension', $extensions);
			}

			if(!empty($data['forums']))
			{
				$sql .= ' AND ' . $db->sql_in_set('t.forum_id', $data['forums']);
			}

			$sql .= ' ORDER BY RAND()';
		}

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('attach');

		$extensions = array();

		$result = $db->sql_query_limit($sql, (int)$data['num']);
		while($row = $db->sql_fetchrow($result))
		{
			if($auth->acl_get('f_download', $row['forum_id']))
			{
				if (!extension_allowed($row['forum_id'], $row['extension'], $extensions))
				{
					continue;
				}

				$l_downloaded_viewed	= 'DOWNLOAD_COUNT';
				$display_cat			= $extensions[$row['extension']]['display_cat'];
				$download_link			= append_sid("{$phpbb_root_path}download/file.$phpEx", 'id=' . $row['attach_id']);

				switch ($display_cat)
				{
					// Images
					case ATTACHMENT_CATEGORY_IMAGE:
					case ATTACHMENT_CATEGORY_THUMB:
						$download_link .= '&amp;mode=view';
					
					// no break

					// Windows Media Streams, Real Media Streams,  Macromedia Flash Files
					case ATTACHMENT_CATEGORY_WM:
					case ATTACHMENT_CATEGORY_RM:
					case ATTACHMENT_CATEGORY_QUICKTIME:
					case ATTACHMENT_CATEGORY_FLASH:
						$l_downloaded_viewed = 'VIEWED_COUNT';
					break;
				}

				if($row['download_count'] != 1)
				{
					$l_downloaded_viewed .= 'S';
				}

				$attach_img_preview = $phpbb_root_path . $this->preview_path . 'image_' . $row['extension'] . '.png';
				if(!file_exists($attach_img_preview))
				{
					$attach_img_preview = $phpbb_root_path . $this->preview_path . 'no_extension.png';
				}

				$template->assign_block_vars('attach', array(
					'S_DATE'			=> $user->lang('ATTACH_DATE', format_short_date($row['filetime'])),

					'S_FILESIZE'		=> $user->lang('ATTACH_SIZE', get_formatted_filesize($row['filesize'])),
					'S_DOWNLOAD'		=> $user->lang("ATTACH_$l_downloaded_viewed", $row['download_count']),
					'S_IMG'				=> '<img src="' . $attach_img_preview . '" width="60" alt="" />',
					'REAL_FILENAME'		=> truncate_string(str_replace(array('_', '-', '.' . $row['extension']), ' ', $row['real_filename']), 20, 255, '...'),
					'U_FILE'			=> $download_link,
					'U_FILELINK'		=> append_sid("{$phpbb_root_path}viewtopic.$phpEx?f=" . $row['forum_id'] . '&amp;p=' . $row['post_msg_id'] . '#p' . $row['post_msg_id']),
				));
			}
		}
		$db->sql_freeresult($result);

		unset($row);
		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				if($submit)
				{
					$new['forums'] = request_var('forums', array(0));
				}
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
		return true;
	}

	function get_config()
	{
		$this->display_vars = array(
			'filename'		=> array('lang' => 'ATTACH_SPECIFIC',	'validate' => 'string',	'type' => 'text:50:255',	'default' => ''),
			'forums'		=> array('lang' => 'ATTACH_FORUM',		'type' => 'custom',		'function' => 'blg_forums_select',	'params' => array('forums', '{CONFIG_VALUE}', 1)),
			'num'			=> array('lang' => 'ATTACH_NUM',		'validate' => 'int',	'type' => 'text:4:3',	'default' => 1),
			'extension'		=> array('lang' => 'ATTACH_EXTENSION',	'validate' => 'string',	'type' => 'text:25:255',	'default' => ''),
		);

		return true;
	}
}
?>
