<?php
/*
*
* @name birthdays_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: birthdays_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class birthdays_block extends blockgets_block
{
	function init()
	{
		global $template, $db, $config, $user;

		$this->tpl_name = 'birthdays_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}

		// Generate birthday list if required ...
		if (!$config['load_birthdays'] || !$config['allow_birthdays'])
		{
			return false;
		}

		$birthday_ary = array();

		$time_now = time() + $user->timezone + $user->dst - date('Z');
		$now = getdate($time_now);

		$days_sql = '';
		for($i = 0; $i < (int)$data['next_days']+1; $i++)
		{
			$day = getdate($time_now + (86400 * $i));
			$days_sql .= (($days_sql) ? ' OR ' : '') . "u.user_birthday LIKE '" . $db->sql_escape(sprintf('%2d-%2d-', $day['mday'], $day['mon'])) . "%'";
		}

		$sql = 'SELECT u.user_id, u.username, u.user_colour, u.user_birthday
			FROM ' . USERS_TABLE . ' u
			LEFT JOIN ' . BANLIST_TABLE . " b ON (u.user_id = b.ban_userid)
			WHERE (b.ban_id IS NULL OR b.ban_exclude = 1)
			AND $days_sql
			AND u.user_type IN (" . USER_NORMAL . ', ' . USER_FOUNDER . ')
			ORDER BY u.username_clean ASC';
		$result = $db->sql_query($sql);

		while ($row = $db->sql_fetchrow($result))
		{
			list($bday, $bmonth, $byear) = explode('-', str_replace(' ', '', $row['user_birthday']));

			if(!(int)$byear)
			{
				$byear = $now['year'];
			}

			$ttime = "{$bday}_$bmonth";
			if(!isset($birthday_ary[$ttime]))
			{
				$birthday_ary[$ttime] = array();
			}

			$btext = get_username_string('full', $row['user_id'], $row['username'], $row['user_colour']);
			if(($age = ($now['year'] - (int)$byear)))
			{
				$btext .= " ($age)";
			}

			$birthday_ary[$ttime][] = $btext;
		}
		$db->sql_freeresult($result);

		asort($birthday_ary);

		$tomorrow = getdate(strtotime('+1 day', $time_now));

		foreach($birthday_ary as $btime => $data)
		{
			list($bday, $bmon) = explode('_', $btime);

			$btitle = 'BIRTHDAYS_FOR';

			if($bday == $now['mday'] && $bmon == $now['mon'])
			{
				$btitle = 'TODAY_BIRTHDAYS';
			}
			
			if($bday == $tomorrow['mday'] && $bmon == $tomorrow['mon'])
			{
				$btitle = 'TOMORROW_BIRTHDAYS';
			}

			list($bday, $bmon) = explode('-', strtr(date('d-F', strtotime("$bmon/$bday")), $user->lang['datetime']));

			$template->assign_block_vars('birthday', array(
				'S_TITLE'	=> sprintf($user->lang[$btitle], $bday, $bmon),
				'S_USERS'	=> implode(', ', $data),
			));
		}

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
		return true;
	}

	function get_config()
	{
		$this->display_vars = array(
			'next_days'		=> array('lang' => 'NEXT_BIRTHDAYS',	'validate' => 'int:0:30',	'type' => 'text:3:2',	'default' => 0),
		);

		return true;
	}
}
?>
