<?php
/*
*
* @name contact_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: contact_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class contact_block extends blockgets_block
{
	function init($method = '')
	{
		global $phpbb_root_path, $template, $config, $user, $phpEx;

		$this->tpl_name = 'contact_block';
		
		if(($data = $this->unserialize()) === false)
		{
			return false;
		}

		$username = $user_email = $subject = $message = '';
		
		if($user->data['user_type'] != USER_IGNORE)
		{
			$username	= $user->data['username'];
			$user_email = $user->data['user_email'];
		}
		else
		{
			$data['hide_user_fields'] = false;
		}
		
		if($method == 'submit')
		{
			$user->add_lang('memberlist');

			$error = $notice = array();

			$username	= utf8_normalize_nfc(request_var('username', $username, true));
			$user_email = request_var('email', $user_email);
			$subject	= utf8_normalize_nfc(request_var('subject', $subject, true));
			$message	= utf8_normalize_nfc(request_var('message', $message, true));

			if(!check_form_key('contact_block'))
			{
				$error[] = $user->lang['FORM_INVALID'];
			}
			
			if (!$username)
			{
				$error[] = $user->lang['EMPTY_NAME_EMAIL'];
			}
			
			if(preg_match('/^' . get_preg_expression('email') . '$/i', $user_email))
			{
				if($data['check_email'] && !$data['hide_user_fields'])
				{
					list(, $domain) = explode('@', $user_email);

					if(phpbb_checkdnsrr($domain, 'A') === false && phpbb_checkdnsrr($domain, 'MX') === false)
					{
						$error[] = $user->lang['EMAIL_INVALID'];
					}
				}
			}
			else
			{
				$error[] = $user->lang['EMAIL_EMPTY'];
			}
			
			if (!$subject)
			{
				$error[] = $user->lang['EMPTY_SUBJECT_EMAIL'];
			}

			if (!$message)
			{
				$error[] = $user->lang['EMPTY_MESSAGE_EMAIL'];
			}

			if(!sizeof($error))
			{
				if(!class_exists('messenger'))
				{
					include_once($phpbb_root_path . 'includes/functions_messenger.' . $phpEx);
				}
				
				$email_lang = ($user->data['is_registered']) ? $user->data['user_lang'] : $config['default_lang'];

				$messenger = new messenger(false);

				$messenger->template($this->master->path . 'contact_block', $email_lang);
				$messenger->from($user_email);
				$messenger->replyto($user_email);
				$messenger->to($data['email'], $config['sitename']);
				$messenger->subject(htmlspecialchars_decode($subject));

				$messenger->headers('X-AntiAbuse: Board servername - ' . $config['server_name']);
				$messenger->headers('X-AntiAbuse: User_id - ' . $user->data['user_id']);
				$messenger->headers('X-AntiAbuse: Username - ' . $username);
				$messenger->headers('X-AntiAbuse: User IP - ' . $user->ip);

				$messenger->assign_vars(array(
					'FROM_USERNAME'	=> htmlspecialchars_decode($username),
					'MESSAGE'		=> htmlspecialchars_decode($message))
				);

				if($messenger->send(NOTIFY_EMAIL))
				{
					$notice[] = $user->lang['EMAIL_SENT'];
				}
				else
				{
					$error[] = $user->lang['CONTACT_ERROR'];
				}
			}

			$template->assign_vars(array(
				'S_SUBMIT'	=> true,
				'S_NOTICE'	=> (sizeof($error) ? implode('<br />', $error) : implode('<br />', $notice)),
				'S_ERROR'	=> (sizeof($error) ? true : false),

				'SUBJECT'	=> (sizeof($error) ? $subject : ''),
				'MESSAGE'	=> (sizeof($error) ? $message : ''),
			));
		}

		add_form_key('contact_block');
		
		$s_hidden_fields = array(
			'jblgm'	=> $this->config['block_id']
		);
		
		if($data['hide_user_fields'])
		{
			$s_hidden_fields = array_merge($s_hidden_fields, array(
				'username'	=> $username,
				'email'		=> $user_email,
			));
		}
		
		$template->assign_vars(array(
			'USERNAME'	=> $username,
			'EMAIL'		=> $user_email,

			'SHOW_USER_FIELDS'	=> ($data['hide_user_fields']) ? false : true,
			'S_SHORT_MODE'		=> ($this->config['autofit']) ? 1 : 0,
			'S_HIDDEN_FIELDS'	=> build_hidden_fields($s_hidden_fields),
			
			'U_ACTION'	=> $this->master->get_board_path('page'),
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		global $config;

		$this->display_vars = array(
			'email'				=> array('lang' => 'CONTACT_EMAIL',			'validate' => 'string',	'type' => 'text:30:255',	'default' => $config['board_contact']),
			'hide_user_fields'	=> array('lang' => 'CONTACT_HIDE_FIELDS',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 0),
			'check_email'		=> array('lang' => 'CONTACT_CHECK_EMAIL',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 0),
		);

		return true;
	}
}

?>