<?php
/*
*
* @name counter_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: counter_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class counter_block extends blockgets_block
{
	function init()
	{
		global $db, $template, $config, $user;

		$this->tpl_name = 'counter_block';
		
		if(($data = $this->unserialize()) === false)
		{
			return false;
		}
		
		if($data['local_count'])
		{
			$counter_visits		= (int)$data['visit_count'];
			$counter_interval	= (int)$data['counter_interval'];
			$count_startdate	= $data['start_date'];
			
			// Set new visit
			$data['visit_count'] = $counter_visits = $counter_visits+1;
			
			$sql = 'UPDATE ' . BLG_BLOCK_TABLE . "
				SET block_content = '" . @serialize($data) . "'
				WHERE block_id = " . $this->config['block_id'];
			$db->sql_query($sql);
		}
		else
		{
			$counter_visits		= (int)$config['blg_counter_visit_count'];
			$counter_interval	= (int)$config['blg_counter_interval'];
			$count_startdate	= $config['blg_counter_start_date'];
		}

		if(!$count_startdate)
		{
			return false;
		}

		// Counter Statistics
		$time_online = time() - $count_startdate;

		$counter_hours	= $time_online / 3600;
		$counter_days	= $time_online / 86400;
		$counter_weeks	= $time_online / 604800;
		$counter_months	= $time_online / 2592000;
		$counter_years	= $time_online / 31536000;
		
		$hits = array(
			'USER'		=> min(($counter_visits / $config['num_users']), $counter_visits),
			'HOUR'		=> min(($counter_visits / $counter_hours), $counter_visits),
			'DAY'		=> min(($counter_visits / $counter_days), $counter_visits),
			'WEEK'		=> min(($counter_visits / $counter_weeks), $counter_visits),
			'MONTH'		=> min(($counter_visits / $counter_months), $counter_visits),
			'YEAR'		=> min(($counter_visits / $counter_years), $counter_visits),
		);

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('counter_hit');
		
		foreach($hits as $lang => $value)
		{
			$template->assign_block_vars('counter_hit', array(
				'S_TITLE'	=> $user->lang['HITS_PER_' . $lang],
				'S_VALUE'	=> sprintf('%.2f', $value),
			));	
		}

		$template->assign_vars(array(
			'L_COUNTER'				=> ($data['local_count']) ? $user->lang['COUNTER_LOCAL'] : $user->lang['COUNTER_TOTAL'],
			'S_COUNTER'				=> preg_replace('#([0-9])#', '<span class="digit-\\1"></span>', sprintf("%08d", $counter_visits)),
			'COUNTER_STARTDATE'		=> $user->lang('COUNTER_STARTDATE', $user->format_date($count_startdate)),
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				if(!isset($_POST['counter_reset']))
				{
					$temp = $this->unserialize($block_row['block_content'], true);
				}
				
				$add = array(
					'start_date'		=> (!empty($temp) ? $temp['start_date'] : time()),
					'visit_count'		=> (!empty($temp) ? $temp['visit_count'] : 0),
				);
				
				$new['block_content'] = $this->serialize($new, $add);
			break;
		}
		return true;
	}

	function get_config()
	{
		$this->display_vars = array(
			'local_count'		=> array('lang' => 'COUNTER_LOCAL',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 0),
			'counter_interval'	=> array('lang' => 'COUNTER_INTERVAL',		'validate' => 'int:300:7200',	'type' => 'text:6:5',	'default' => 1800),
			'reset'				=> array('lang' => 'COUNTER_RESET',	'type' => 'custom', 'function' => 'blg_counter_rst',	'params' => array('acp_block_form')),
		);

		return true;
	}
}
?>
