<?php
/*
*
* @name forum_categories_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: forum_categories_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class forum_categories_block extends blockgets_block
{
	function init()
	{
		global $db, $auth, $user, $template, $phpbb_root_path, $phpEx, $config;

		$this->tpl_name = 'forum_categories_block';

		$forum_rows = $forum_ids = array();
		$parent_id = $visible_forums = 0;

		$root_data = array('forum_id' => 0);

		$sql_array = array(
			'SELECT'	=> 'f.*',
			'FROM'		=> array(
				FORUMS_TABLE		=> 'f'
			),
			'LEFT_JOIN'	=> array(),
		);

		if ($config['load_db_lastread'] && $user->data['is_registered'])
		{
			$sql_array['LEFT_JOIN'][] = array('FROM' => array(FORUMS_TRACK_TABLE => 'ft'), 'ON' => 'ft.user_id = ' . $user->data['user_id'] . ' AND ft.forum_id = f.forum_id');
			$sql_array['SELECT'] .= ', ft.mark_time';
		}
		else if ($config['load_anon_lastread'] || $user->data['is_registered'])
		{
			$tracking_topics = (isset($_COOKIE[$config['cookie_name'] . '_track'])) ? ((STRIP) ? stripslashes($_COOKIE[$config['cookie_name'] . '_track']) : $_COOKIE[$config['cookie_name'] . '_track']) : '';
			$tracking_topics = ($tracking_topics) ? tracking_unserialize($tracking_topics) : array();

			if (!$user->data['is_registered'])
			{
				$user->data['user_lastmark'] = (isset($tracking_topics['l'])) ? (int) (base_convert($tracking_topics['l'], 36, 10) + $config['board_startdate']) : 0;
			}
		}

		$sql = $db->sql_build_query('SELECT', array(
			'SELECT'	=> $sql_array['SELECT'],
			'FROM'		=> $sql_array['FROM'],
			'LEFT_JOIN'	=> $sql_array['LEFT_JOIN'],

			'ORDER_BY'	=> 'f.left_id',
		));

		$result = $db->sql_query($sql);

		$forum_tracking_info = array();
		$branch_root_id = $root_data['forum_id'];

		// Check for unread global announcements (index page only)
		$ga_unread = false;
		$unread_ga_list = get_unread_topics($user->data['user_id'], 'AND t.forum_id = 0', '', 1);

		if (!empty($unread_ga_list))
		{
			$ga_unread = true;
		}
		unset($unread_ga_list);

		while ($row = $db->sql_fetchrow($result))
		{
			$forum_id = $row['forum_id'];

			// Category with no members
			if ($row['forum_type'] == FORUM_CAT && ($row['left_id'] + 1 == $row['right_id']))
			{
				continue;
			}

			// Skip branch
			if (isset($right_id))
			{
				if ($row['left_id'] < $right_id)
				{
					continue;
				}
				unset($right_id);
			}

			if (!$auth->acl_get('f_list', $forum_id))
			{
				// if the user does not have permissions to list this forum, skip everything until next branch
				$right_id = $row['right_id'];
				continue;
			}

			$forum_ids[] = $forum_id;

			if ($config['load_db_lastread'] && $user->data['is_registered'])
			{
				$forum_tracking_info[$forum_id] = (!empty($row['mark_time'])) ? $row['mark_time'] : $user->data['user_lastmark'];
			}
			else if ($config['load_anon_lastread'] || $user->data['is_registered'])
			{
				if (!$user->data['is_registered'])
				{
					$user->data['user_lastmark'] = (isset($tracking_topics['l'])) ? (int) (base_convert($tracking_topics['l'], 36, 10) + $config['board_startdate']) : 0;
				}
				$forum_tracking_info[$forum_id] = (isset($tracking_topics['f'][$forum_id])) ? (int) (base_convert($tracking_topics['f'][$forum_id], 36, 10) + $config['board_startdate']) : $user->data['user_lastmark'];
			}

			// Count the difference of real to public topics, so we can display an information to moderators
			$approve_auth = $auth->acl_get('m_approve', $forum_id);

			$row['forum_id_unapproved_topics'] = ($approve_auth && ($row['forum_topics_real'] != $row['forum_topics'])) ? $forum_id : 0;
			$row['forum_topics'] = ($approve_auth) ? $row['forum_topics_real'] : $row['forum_topics'];

			//
			if ($row['parent_id'] == $root_data['forum_id'] || $row['parent_id'] == $branch_root_id)
			{
				// Direct child of current branch
				$parent_id = $forum_id;
				$forum_rows[$forum_id] = $row;

				if ($row['forum_type'] == FORUM_CAT && $row['parent_id'] == $root_data['forum_id'])
				{
					$branch_root_id = $forum_id;
				}
				$forum_rows[$parent_id]['forum_id_last_post'] = $row['forum_id'];
				$forum_rows[$parent_id]['orig_forum_last_post_time'] = $row['forum_last_post_time'];
			}
			else if ($row['forum_type'] != FORUM_CAT)
			{
				$subforums[$parent_id][$forum_id]['display'] = ($row['display_on_index']) ? true : false;
				$subforums[$parent_id][$forum_id]['name'] = $row['forum_name'];
				$subforums[$parent_id][$forum_id]['orig_forum_last_post_time'] = $row['forum_last_post_time'];
				$subforums[$parent_id][$forum_id]['children'] = array();

				if (isset($subforums[$parent_id][$row['parent_id']]) && !$row['display_on_index'])
				{
					$subforums[$parent_id][$row['parent_id']]['children'][] = $forum_id;
				}

				if (!$forum_rows[$parent_id]['forum_id_unapproved_topics'] && $row['forum_id_unapproved_topics'])
				{
					$forum_rows[$parent_id]['forum_id_unapproved_topics'] = $forum_id;
				}

				$forum_rows[$parent_id]['forum_topics'] += $row['forum_topics'];

				// Do not list redirects in LINK Forums as Posts.
				if ($row['forum_type'] != FORUM_LINK)
				{
					$forum_rows[$parent_id]['forum_posts'] += $row['forum_posts'];
				}
			}
		}
		$db->sql_freeresult($result);

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('forum_row');

		// Used to tell whatever we have to create a dummy category or not.
		$last_catless = true;
		foreach ($forum_rows as $row)
		{
			// Empty category
			if ($row['parent_id'] == $root_data['forum_id'] && $row['forum_type'] == FORUM_CAT)
			{
				$template->assign_block_vars('forum_row', array(
					'S_IS_CAT'				=> true,
					'FORUM_ID'				=> $row['forum_id'],
					'FORUM_NAME'			=> $row['forum_name'],
					'FORUM_FOLDER_IMG'		=> '',
					'U_VIEWFORUM'			=> append_sid("{$phpbb_root_path}viewforum.$phpEx", 'f=' . $row['forum_id']))
				);

				continue;
			}

			$visible_forums++;
			$forum_id = $row['forum_id'];

			$forum_unread = (isset($forum_tracking_info[$forum_id]) && $row['orig_forum_last_post_time'] > $forum_tracking_info[$forum_id]) ? true : false;

			// Mark the first visible forum on index as unread if there's any unread global announcement
			if ($ga_unread && $visible_forums == 1)
			{
				$forum_unread = true;
			}

			$folder_alt = '';
			$subforums_list = array();

			$folder_image = ($forum_unread) ? 'folder_unread' : 'folder';

			// Generate list of subforums if we need to
			if (isset($subforums[$forum_id]))
			{
				foreach ($subforums[$forum_id] as $subforum_id => $subforum_row)
				{
					$subforum_unread = (isset($forum_tracking_info[$subforum_id]) && $subforum_row['orig_forum_last_post_time'] > $forum_tracking_info[$subforum_id]) ? true : false;

					if (!$subforum_unread && !empty($subforum_row['children']))
					{
						foreach ($subforum_row['children'] as $child_id)
						{
							if (isset($forum_tracking_info[$child_id]) && $subforums[$forum_id][$child_id]['orig_forum_last_post_time'] > $forum_tracking_info[$child_id])
							{
								// Once we found an unread child forum, we can drop out of this loop
								$subforum_unread = true;
								break;
							}
						}
					}

					// If one subforum is unread the forum gets unread too...
					if ($subforum_unread)
					{
						$forum_unread = true;
					}
				}
			}
			else if($row['forum_type'] == FORUM_LINK)
			{
				$folder_image = 'link';
			}

			// Which folder should we display?
			if ($row['forum_status'] == ITEM_LOCKED)
			{
				$folder_alt = 'FORUM_LOCKED';
			}
			else
			{
				$folder_alt = ($forum_unread) ? 'UNREAD_POSTS' : 'NO_UNREAD_POSTS';
			}

			$catless = ($row['parent_id'] == $root_data['forum_id']) ? true : false;

			if ($row['forum_type'] != FORUM_LINK)
			{
				$u_viewforum = append_sid("{$phpbb_root_path}viewforum.$phpEx", 'f=' . $row['forum_id']);
			}
			else
			{
				// If the forum is a link and we count redirects we need to visit it
				// If the forum is having a password or no read access we do not expose the link, but instead handle it in viewforum
				if (($row['forum_flags'] & FORUM_FLAG_LINK_TRACK) || $row['forum_password'] || !$auth->acl_get('f_read', $forum_id))
				{
					$u_viewforum = append_sid("{$phpbb_root_path}viewforum.$phpEx", 'f=' . $row['forum_id']);
				}
				else
				{
					$u_viewforum = $row['forum_link'];
				}
			}

			$folder_image = "{$phpbb_root_path}blockgets/images/icons/$folder_image.png";

			$template->assign_block_vars('forum_row', array(
				'S_IS_CAT'			=> false,
				'S_NO_CAT'			=> $catless && !$last_catless,
				'S_IS_LINK'			=> ($row['forum_type'] == FORUM_LINK) ? true : false,

				'FORUM_ID'			=> $row['forum_id'],
				'FORUM_NAME'		=> $row['forum_name'],
				'FORUM_FOLDER_IMG'	=> '<img src="' . $folder_image . '" alt="" title="' . $user->lang[$folder_alt] . '" />',
				'U_VIEWFORUM'		=> $u_viewforum,
			));

			$last_catless = $catless;
		}

		return true;
	}

	function configure()
	{
	}

	function get_config()
	{
		return false;
	}
}

?>
