<?php
/*
*
* @name gallery_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: gallery_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class gallery_block extends blockgets_block
{
	function init()
	{
		global $template, $db, $auth, $phpbb_root_path, $phpEx;

		$this->tpl_name = 'gallery_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}
		
		$sql_query = '';
		$topic_ids = $post_ids = $images = array();
		
		switch($data['gallery_type'])
		{
			case 'forums':
				if(!empty($data['gallery_forums']))
				{
					foreach($data['gallery_forums'] as $id => $forum_id)
					{
						if(!$auth->acl_get('f_download', $forum_id))
						{
							unset($data['gallery_forums'][$id]);
						}
					}
	
					if(!empty($data['gallery_forums']))
					{
						$sql_query = 'WHERE ' . $db->sql_in_set('t.forum_id', $data['gallery_forums']);
					}
				}
			break;
			
			case 'topics':
				foreach(explode(',', $data['gallery_topics']) as $topic_id)
				{
					$topic_id = (int)trim($topic_id);
					$topic_ids[$topic_id] = $topic_id;
				}
				
				if(!empty($topic_ids))
				{
					$sql = 'SELECT topic_id, forum_id
						FROM ' . TOPICS_TABLE . '
						WHERE ' . $db->sql_in_set('topic_id', $topic_ids);
					$result = $db->sql_query($sql);
					while($row = $db->sql_fetchrow($result))
					{
						if(!$auth->acl_get('f_download', $row['forum_id']))
						{
							unset($topic_ids[$row['topic_id']]);
						}
					}
					$db->sql_freeresult($result);

					if(!empty($topic_ids))
					{
						$sql_query = 'WHERE ' . $db->sql_in_set('a.topic_id', $topic_ids);
					}
				}
			break;
			
			case 'posts':
				foreach(explode(',', $data['gallery_posts']) as $post_id)
				{
					$post_id = (int)trim($post_id);
					$post_ids[$post_id] = $post_id;
				}
				
				if(!empty($post_ids))
				{
					$sql = 'SELECT post_id, forum_id
						FROM ' . POSTS_TABLE . '
						WHERE ' . $db->sql_in_set('post_id', $post_ids);
					$result = $db->sql_query($sql);
					while($row = $db->sql_fetchrow($result))
					{
						if(!$auth->acl_get('f_download', $row['forum_id']))
						{
							unset($post_ids[$row['post_id']]);
						}
					}
					$db->sql_freeresult($result);

					if(!empty($post_ids))
					{
						$sql_query = 'WHERE ' . $db->sql_in_set('a.post_msg_id', $post_ids);
					}
				}
			break;
			
			case 'custom':
				if(!empty($data['gallery_custom']))
				{
					foreach($data['gallery_custom'] as $img)
					{
						$img_info = blg_explode_list($img, 2);
						$images[] = array('src'	=> $img_info[1]);
					}
				}
			break;
		}

		if($sql_query)
		{
			$download_link	= append_sid("{$phpbb_root_path}download/file.$phpEx", 'mode=view');
	
			$sql = 'SELECT a.*, t.forum_id
				FROM ' . ATTACHMENTS_TABLE . ' a
					LEFT JOIN ' . TOPICS_TABLE . " t ON(t.topic_id = a.topic_id)
				$sql_query
				AND " . $db->sql_in_set('a.extension', array('jpg', 'gif', 'png')) . '
				AND a.is_orphan = 0
				AND a.filesize > 0
				ORDER BY RAND()';
			$result = $db->sql_query_limit($sql, 50);
			while($row = $db->sql_fetchrow($result))
			{
				$images[] = array(
					'src'	=> $download_link . '&amp;id=' . $row['attach_id'],
					'url'	=> append_sid("{$phpbb_root_path}viewtopic.$phpEx?f=" . $row['forum_id'] . '&amp;p=' . $row['post_msg_id'] . '#p' . $row['post_msg_id']),
				);
			}
		}

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('image');
		
		if(empty($images))
		{
			return false;	
		}

		foreach($images as $row)
		{
			$template->assign_block_vars('image', array(	
				'SRC' 		=> $row['src'],
				'TITLE'		=> (isset($row['title']) ? $row['title'] : ''),
				'ACTION' 	=> (isset($row['url']) ? $row['url'] : $row['src']),		
			));
		}

		$template->assign_vars(array(
			'S_GALLERY_HEIGHT'		=> $data['gallery_height'],
			'S_GALLERY_MARGIN'		=> $data['image_margin'],
			'S_GALLERY_FPS'			=> $data['gallery_fps'],
			'S_GALLERY_DIRECTION'	=> $data['gallery_dir'],
			'S_GALLERY_ZOOM'		=> $data['image_zoom'],
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				if($submit)
				{
					$new['gallery_forums'] = request_var('forums', array(0));
				}
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['gallery_custom'] = utf8_normalize_nfc(request_var('img', array('' => ''), true));

				$new['block_content'] = $this->serialize($new);
			break;
		}
		return true;
	}

	function get_config()
	{
		$gallery_types = array(
			'forums'	=> 'GALLERY_TYPE_FORUMS',
			'topics'	=> 'GALLERY_TYPE_TOPICS',
			'posts' 	=> 'GALLERY_TYPE_POSTS',
			'custom'	=> 'GALLERY_TYPE_CUSTOM',
		);
		
		$dialog_items = array(
			array('IMG_TITLE'),
			array('IMG_URL', array('/^http[s]?:\/\/(.*)\.(jpg|gif|png)$/'))
		);

		$this->display_vars = array(
			'gallery_height'	=> array('lang' => 'GALLERY_HEIGHT',	'validate' => 'int',		'type' => 'text:4:3',	'default' => 100),
			'gallery_fps'		=> array('lang' => 'GALLERY_FPS',		'validate' => 'int:1:10',	'type' => 'text:3:2',	'default' => 4),
			'gallery_dir'		=> array('lang' => 'GALLERY_DIRECTION',	'validate' => 'string',		'type' => 'select', 'function' => 'make_scroll_select', 'params' => array('{CONFIG_VALUE}', 'direction_x'),  'default' => 'left'),
			'image_margin'		=> array('lang' => 'GALLERY_MARGIN',	'validate' => 'int',		'type' => 'text:3:3',	'default' => 4),
			'image_zoom'		=> array('lang' => 'GALLERY_ZOOM',		'validate' => 'int:1:10',	'type' => 'text:3:2',	'default' => 2),
			'gallery_type'		=> array('lang' => 'GALLERY_TYPE',		'validate' => 'string',		'type' => 'select', 'function' => 'blg_make_select', 'params' => array($gallery_types, '{CONFIG_VALUE}'),  'default' => 'custom'),
			'gallery_forums'	=> array('lang' => 'GALLERY_FORUMS',	'type' => 'custom',		'function' => 'blg_forums_select',	'params' => array('forums', '{CONFIG_VALUE}', 1)),
			'gallery_topics'	=> array('lang' => 'GALLERY_TOPICS',	'validate' => 'string',		'type' => 'text:40:255'),
			'gallery_posts'		=> array('lang' => 'GALLERY_POSTS',		'validate' => 'string',		'type' => 'text:40:255'),
			'gallery_custom'	=> array('lang' => 'GALLERY_CUSTOM',	'type' => 'custom', 		'function' => 'blg_build_list',	'params' => array('imglist', 'img', '{CONFIG_VALUE}', $dialog_items)),
		);

		return true;
	}
}

?>
