<?php
/*
*
* @name recent_topics_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: recent_topics_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class recent_topics_block extends blockgets_block
{
	function init()
	{
		global $phpbb_root_path, $template, $db, $auth, $user, $phpEx;

		$this->tpl_name = 'recent_topics_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}
		
		$forum_ids = array();
		
		// Use selected forums if set, else, use all forums
		if(!empty($data['forums']))
		{
			foreach($data['forums'] as $forum_id)
			{
				if($auth->acl_get('f_read', $forum_id))
				{
					$forum_ids[] = $forum_id;
				}
			}
		}
		else
		{
			$forum_ids = array_keys($auth->acl_getf('f_read', true));
		}

		if(!sizeof($forum_ids))
		{
			return true;
		}

		$sql_ary = array(
			'RECENT_TOPICS' => ') ORDER BY topic_time DESC',

			'RECENT_REPLIES' => 'AND topic_replies > 0)
				ORDER BY topic_last_post_time DESC',

			'RECENT_ANN' => 'AND topic_type = ' . POST_ANNOUNCE . ')
				OR (forum_id = 0 AND ' . POST_GLOBAL . ')
				ORDER BY topic_time DESC',
		);
		
		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('recent');

		foreach($sql_ary as $tab_title => $sql)
		{
			$query = 'SELECT forum_id, topic_id, topic_replies, topic_views, topic_time, topic_title,
				topic_poster, topic_first_poster_name, topic_first_poster_colour, topic_last_post_id
				FROM ' . TOPICS_TABLE . '
				WHERE topic_status <> ' . ITEM_MOVED . '
				AND topic_approved = 1
				AND (' . $db->sql_in_set('forum_id', $forum_ids) . "
				$sql";
			$result = $db->sql_query_limit($query, (int)$data['topic_limit']);
			
			$sql_ary[$tab_title] = array();
			
			while($row = $db->sql_fetchrow($result))
			{
				$sql_ary[$tab_title][] = $row;
			}
			$db->sql_freeresult($result);
		}
		
		foreach($sql_ary as $tab_title => $rows)
		{
			$template->assign_block_vars('recent', array(
				'S_LEGEND'			=> $user->lang[$tab_title],
				'S_LEGEND_EMPTY'	=> (!sizeof($rows) ? $user->lang['NO_' . $tab_title] : ''),
				'S_TAB_ID'			=> strtolower($tab_title),
			));
			
			foreach($rows as $row)
			{
				$row['topic_title'] = censor_text($row['topic_title']);

				$template->assign_block_vars('recent', array(
					'POST_AUTHOR_FULL'		=> get_username_string('full', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),

					'REPLIES'         		=> $row['topic_replies'],
					'TOPIC_VIEWS'      		=> $row['topic_views'],
					'TOPIC_TIME'   			=> $user->format_date($row['topic_time']),
					'U_LAST_COMMENTS'   	=> append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;p=' . $row['topic_last_post_id'] . '#p' . $row['topic_last_post_id']),

					'MINI_POST_IMG'      	=> $user->img('icon_post_target', 'POST'),
					'TITLE'             	=> truncate_string($row['topic_title'], $data['title_limit'], 255, false, '...'),
					'FULL_TITLE'      		=> str_replace(array('&quot;', '"'), "'", $row['topic_title']),
					'U_VIEW_TOPIC'      	=> append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;t=' . $row['topic_id']),
				));
			}
		}
		
		$template->assign_var('S_SHORT_MODE', $this->config['autofit']);

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				if($submit)
				{
					$new['forums'] = request_var('forums', array(0));
				}
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$this->display_vars = array(
			'topic_limit'	=> array('lang' => 'RECENT_TOPIC_LIMIT',	'validate' => 'int:1:100',	'type' => 'text:4:3',	'default' => 5),
			'title_limit'	=> array('lang' => 'TITLE_LIMIT',			'validate' => 'int:1:255',	'type' => 'text:4:3',	'default' => 50),
			'forums'		=> array('lang' => 'RECENT_FORUMS',			'type' => 'custom',			'function' => 'blg_forums_select',	'params' => array('forums', '{CONFIG_VALUE}', 1)),
		);

		return true;
	}
}
?>
