<?php
/*
*
* @name rss_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: rss_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class rss_block extends blockgets_block
{
	var $data = array(
		'encoding'	=> 'UTF-8',
		'type'		=> '',
	);

	var $rss_data;
	var $rss_type;
	var $rss_ttl = 86400;
	
	var $tags = array(
		'rss'	=> array('name'	=> 'channel', 	'tags'	=> 'item|image'),
		'feed'	=> array('name'	=> 'feed', 		'tags'	=> 'entry'),
	);

	function init()
	{
		global $template, $user;

		$this->tpl_name = 'rss_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}
		
		$limit			= $data['limit'];
		$ignore_lang 	= $data['ignore_lang'];
		
		// Force vertical direction
		if($data['collapsable'])
		{
			$data['direction'] = BLG_SCROLL_V;
		}
		
		$template->assign_vars(array(
			'S_RSS_COLLAPSE'	=> (int)$data['collapsable'],
			'S_BLOCK_HEIGHT'	=> $data['height'],
			'S_SCROLL_V'		=> ($data['direction'] == BLG_SCROLL_V) ? true : false,
			'S_SCROLL_H'		=> ($data['direction'] == BLG_SCROLL_H) ? true : false,
		));

		// Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('rss');
		
		$this->rss_ttl = (int)$data['ttl'];
		
		if(empty($data['sources']))
		{
			return false;
		}

		foreach($data['sources'] as $source)
		{
			list($title, $url) = blg_explode_list($source, 2);
			
			$this->read($url);

			switch($this->rss_type)
			{
				case 'rss':
					if(!$ignore_lang && $user->lang_name != $this->get(false, 'language'))
					{
						continue;
					}
			
					$template->assign_block_vars('rss', array(
						'S_TITLE'	=> $this->get(false, 'title'),
					));
			
					$entries	= $this->get('item');
					$limit		= min($limit, count($entries));
					
					for($i = 0; $i < $limit; $i++)
					{
						$template->assign_block_vars('rss.item', array(
							'S_TITLE'		=> $this->get($i, 'title', $entries),
							'S_DESCRIPTION'	=> $this->_clear($this->get($i, 'description', $entries), $data),
							'U_LINK'		=> $this->get($i, 'link', $entries),
						));
					}
				break;
				
				case 'feed':
					if($ignore_lang && $user->lang_name != $this->rss_data['language'])
					{
						continue;
					}
			
					$template->assign_block_vars('rss', array(
						'S_TITLE'	=> $this->get(false, 'title'),
					));
			
					$entries	= $this->get('entry');
					$limit		= min($limit, count($entries));
					
					for($i = 0; $i < $limit; $i++)
					{
						$template->assign_block_vars('rss.item', array(
							'S_TITLE'		=> $this->get($i, 'title', $entries),
							'S_DESCRIPTION'	=> $this->_clear($this->get($i, 'content', $entries), $data),
							'U_LINK'		=> $this->get($i, 'id', $entries),
						));
					}
				break;	
			}
		}

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['sources'] = utf8_normalize_nfc(request_var('source', array('' => ''), true));

				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$dir_options = array(
			BLG_SCROLL_H	=> 'LIST_SCROLL_H',
			BLG_SCROLL_V	=> 'LIST_SCROLL_V',
		);

		$ttl_options = array(
			3600	=> '1_HOUR',
			7200	=> '2_HOURS',
			21600	=> '6_HOURS',
			86400	=> '1_DAY',
			604800	=> '7_DAYS',
		);
		
		$dialog_items = array(
			array('RSS_TITLE'),
			array('RSS_URL', array('/^http[s]?:\/\/(.*)$/'))
		);
		
		$this->display_vars = array(
			'limit'			=> array('lang' => 'RSS_LIMIT',			'validate' => 'int',	'type' => 'text:6:5',		'default' => 5),
			'ignore_lang'	=> array('lang' => 'RSS_IGNORE_LANG',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 1),
			'sources'		=> array('lang' => 'RSS_SOURCES',		'type' => 'custom', 	'function' => 'blg_build_list',	'params' => array('sourcelist', 'source', '{CONFIG_VALUE}', $dialog_items)),
			'direction'		=> array('lang' => 'RSS_DIRECTION',		'validate' => 'int', 	'type' => 'select',		'function' => 'blg_make_select',	'params' => array($dir_options, '{CONFIG_VALUE}'),	'default' => BLG_SCROLL_V),
			'collapsable'	=> array('lang' => 'RSS_COLLAPSABLE',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 1),
			'height'  		=> array('lang' => 'RSS_HEIGHT',		'validate' => 'int', 	'type' => 'text:4:3',	'default' => 150),
			'ttl'  			=> array('lang' => 'RSS_TTL',			'validate' => 'int', 	'type' => 'select',		'function' => 'blg_make_select',	'params' => array($ttl_options, '{CONFIG_VALUE}'),	'default' => 86400),
		);

		return true;
	}
	
	function _clear($text, $data)
	{
		$replaces = array(
			'#<object([^>]+)>.*?</object>#is',
			'#<blockquote>.*?</blockquote>#is',
			'#<\/?[^>]+>#s'
		);
		
		// Delete objects and line breaks
		if($data['direction'] == BLG_SCROLL_H)
		{
			$text = preg_replace($replaces, '', $text);
			$text = str_replace(array("\r", "\n", '<br />'), ' ', $text);
		}
		
		return $text;
	}
	
	function read($url)
	{
		global $cache;
		
		if(!$url)
		{
			return false;
		}
		
		/* Reset the values */
		$this->rss_type = '';
		$this->rss_data = $this->data;

		$file_id = '_rss_' . md5($url);
		
		if(($this->rss_data = $cache->get($file_id)) === false)
		{
			$file_text = @file_get_contents(str_replace('&amp;', '&', $url));
			
			if(!$file_text)
			{
				return false;
			}
			
			// Get Encoding
			$this->rss_data['encoding'] = $this->data['encoding'];

			if(preg_match('#encoding=[\'\"]+([\w\d\-\_]+)[\'\"]+#', $file_text, $out))
			{
				$this->rss_data['encoding'] = $out[1];
			}
			
			// Determine the rss type and language
			preg_match('#<(rss|feed)+.*?(?:xml:lang\=\"([a-z\-]+)\")?[^>]?>#', $file_text, $out);
			
			switch($out[1])
			{
				case 'rss':
				case 'feed':
					$this->rss_type = $this->rss_data['type'] = $out[1];
					
					if(!empty($out[2]))
					{
						$this->rss_data['language'] = $out[2];
					}

					$this->_get($file_text);
				break;
				
				default:
					return false;
				break;	
			}
			
			$cache->put($file_id, $this->rss_data, $this->rss_ttl);
		}
		
		$this->rss_type = $this->rss_data['type'];
		
		return true;
	}
	
	function get($id, $name = '', $ary = false)
	{
		if($name)
		{
			if($id === false)
			{
				$ary = $this->rss_data[$this->tags[$this->rss_type]['name']];

				return (isset($ary[$name]) ? $ary[$name] : '');
			}
			else if(is_array($ary) && isset($ary[$id][$name]))
			{
				return $ary[$id][$name];
			}

			return '';
		}

		if(isset($this->rss_data[$id]))
		{
			return $this->rss_data[$id];
		}
		
		return array();
	}
	
	function _get($file_text)
	{
		$channel_name = $this->tags[$this->rss_type]['name'];

		if(!preg_match('#<(' . $channel_name . ').*?>(.*?)<\/\\1>#si', $file_text, $out_channel))
		{
			return false;
		}
		
		$file_text = $out_channel[2];
		unset($out_channel);

		// Get the item,  textinput and image variables
		while(preg_match('#<(' . $this->tags[$this->rss_type]['tags'] . ').*?>(.*?)<\/\\1>#si', $file_text, $out))
		{
			if(!isset($this->rss_data[$out[1]]))
			{
				$this->rss_data[$out[1]] = array();
			}
			
			$this->rss_data[$out[1]][] = $this->_compose($out[2]);

			$file_text = str_replace($out[0], '', $file_text);
		}
		
		// And finally, get the channel variables
		$this->rss_data[$channel_name] = $this->_compose($file_text);
	}

	function adjust($text)
	{
		$text = str_replace(array('<![CDATA[', ']]>'), '', $text);
		
		$text = trim($text);
		
		$text = preg_replace('#<img[^>]*src="([^"]*)"[^>]*/?>#', '<img src="\\1" />', $text);
		
		if($text && $this->rss_data['encoding'] != $this->data['encoding'])
		{
			$text = iconv($this->rss_data['encoding'], $this->data['encoding'] . '//TRANSLIT', $text);
		}

		return $text;	
	}

	function _compose($text)
	{
		$ary = array();
		
		preg_match_all('#<([\w\:]+)[^>]*>(.*?)<\/\\1>#si', $text, $out, PREG_SET_ORDER);

		foreach($out as $r)
		{
			$ary[$r[1]] = $this->adjust($r[2]);
		}
		
		return $ary;
	}
}
?>
