<?php
/*
*
* @name share_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: share_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class share_block extends blockgets_block
{
	var $buttons = array(
		'google'	=> array('id' => 1,	'small' => 'size="medium" count="false",60*25',	'medium' => 'size="medium",70*20',	'big' => 'size="tall",72*62'),
		'twitter'	=> array('id' => 2,	'small' => 'none,60*25',		'medium' => 'horizontal,95*21',	'big' => 'vertical,72*62'),
		'facebook'	=> array('id' => 3,	'small' => 'standard,280*25',	'medium' => 'button_count,100*21',	'big' => 'box_count,72*62'),
		'linkedin'	=> array('id' => 4,	'small' => ',0*0',		'medium' => 'right,0*0',	'big' => 'top,0*0'),
		'tuenti'	=> array('id' => 5),
	);

	function init()
	{
		global $user, $template;

		$this->tpl_name = 'share_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}

		if(empty($data['share_buttons']))
		{
			return false;
		}

		// Use the defined url or filter the url to the actual page
		$share_url = (!empty($data['share_url']) ? $data['share_url'] : $this->get_share_url());

		foreach($this->buttons as $button_id => $params)
		{
			$tpl	= 'S_' . strtoupper($button_id);
			$show	= false;

			if(in_array($params['id'], $data['share_buttons']))
			{
				if(isset($params[$data['share_size']]))
				{
					if(preg_match('#([a-z\-_\"=]+),([0-9]+)\*([0-9]+)#', $params[$data['share_size']], $btn_size))
					{
						$template->assign_vars(array(
							$tpl . '_SIZE'		=> $btn_size[1],
							$tpl . '_STYLE'		=> 'width:' . $btn_size[2] . 'px;height:' . $btn_size[3] . 'px;',
						));
					}
				}

				$show = true;
			}

			$template->assign_var($tpl . '_SHOW', $show);
		}

		$template->assign_vars(array(
			'S_SHARE_LANG'			=> $user->lang_name,
			'S_SHARE_LOCALE'		=> $this->master->locale_lang(),
			'U_SHARE_URL'			=> $share_url,
			'U_SHARE_URL_ENCODED'	=> urlencode($share_url),
			
			'S_SHORT_MODE'			=> $this->config['autofit'],
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['share_buttons'] = request_var('button', array(0));
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$this->display_vars = array(
			'share_size'	=> array('lang' => 'SHARE_SIZE',	'validate' => 'string',			'type' => 'select',			'function' => 'build_share_select',	'params' => array('sizes', '{CONFIG_VALUE}'),	'default' => 1),
			'share_url'		=> array('lang' => 'SHARE_URL',		'validate' => 'string:0:255',	'type' => 'text:40:255',	'default' => ''),
			'share_buttons'	=> array('lang' => 'SHARE_BUTTONS',	'type' => 'custom',	'function' => 'build_share_select',	'params' => array('buttons', '{CONFIG_VALUE}', $this->buttons)),
		);

		return true;
	}

	function get_share_url()
	{
		global $user;

		$share_url = $this->master->get_board_path('page');

		/*
		* Tags to delete from url and conditionals to delete
		* param => conditionals (Delete param if conditional1 or conditional2 or .... if present in the url)
		*/
		$strip_tags = array(
			'sid'	=> 1,
			'style'	=> 1,
			'start'	=> 1,
			'f'		=> array('t', 'p'),
			'p'		=> 't',
		);

		// Delete the anchor if its present
		if(($anchor_pos = strpos($share_url, '#')) !== false)
		{
			$share_url = substr($share_url, 0, $anchor_pos);
		}

		if (strpos($share_url, '?') !== false)
		{
			// Separe args and url
			$delim_pos = strpos($share_url, '?');

			$args = substr($share_url, $delim_pos + 1);
			$args = ($args) ? explode('&', str_replace('&amp;', '&', $args)) : array();
			$share_url = substr($share_url, 0, $delim_pos);

			// Create array with args
			$query = array();
			foreach ($args as $argument)
			{
				if($argument)
				{
					$arguments = explode('=', $argument, 2);
					$query[$arguments[0]] = $argument;
				}
			}
			unset($args);

			foreach($strip_tags as $delete_tag => $conditions)
			{
				if(!isset($query[$delete_tag]))
				{
					continue;
				}

				if(!is_array($conditions))
				{
					$conditions = array($conditions);
				}

				foreach($conditions as $condition)
				{
					if($condition == 1 || isset($query[$condition]))
					{
						unset($query[$delete_tag]);
						break;
					}
				}
			}

			// Compose the url
			if(!empty($query))
			{
				$share_url .= '?' . implode('&amp;', $query);
			}
		}

		return $share_url;
	}
}
?>
