<?php
/*
*
* @name stats_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: stats_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class stats_block extends blockgets_block
{
	function init()
	{
		global $template, $config, $user, $phpEx;

		$this->tpl_name = 'stats_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}

		// Set some stats, get posts count from forums data if we... hum... retrieve all forums data
		$total_posts	= $config['num_posts'];
		$total_topics	= $config['num_topics'];
		$total_users	= $config['num_users'];
		$board_days		= ceil((time() - $config['board_startdate']) / 86400);

		$stats = array();

		if($user->data['user_id'] != ANONYMOUS)
		{
			$stats[] = array(
				'legend'	=> 'ST_NEW',
				'sep'		=> false,

				'POSTS'		=> $this->get_stat('newposttotal'),
				'TOPICS'	=> $this->get_stat('newtopictotal'),
				'ANNS'		=> $this->get_stat('newannouncmenttotal'),
				'STICKYS'	=> $this->get_stat('newstickytotal'),
			);
		}

		$stats[] = array(
			'legend'	=> 'ST_TOP',
			'sep'		=> false,

			'POSTS'		=> $total_posts,
			'TOPICS'	=> $total_topics,
			'ANNS'		=> $this->get_stat('announcmenttotal'),
			'STICKYS'	=> $this->get_stat('stickytotal'),
		);

		$stats[] = array(
			'sep'		=> true,

			'TOPICS_PER_DAY'	=> (!$board_days) ? 0 : min(round($total_topics / $board_days, 0), $total_topics),	
			'POSTS_PER_DAY'		=> (!$board_days) ? 0 : min(round($total_posts  / $board_days, 0), $total_posts),	
			'USERS_PER_DAY'		=> (!$board_days) ? 0 : min(round($total_users  / $board_days, 0), $total_users),	
			'TOPICS_PER_USER'	=> (!$total_users) ? 0 : min(round($total_topics / $total_users, 0), $total_topics),	
			'POSTS_PER_USER'	=> (!$total_users) ? 0 : min(round($total_posts  / $total_users, 0), $total_posts),	
			'POSTS_PER_TOPIC'	=> (!$total_topics) ? 0 : min(round($total_posts  / $total_topics, 0), $total_posts),
		);

		$stats[] = array(
			'sep'		=> true,

			'ATTACHMENTS'		=> sprintf('%d (%s)', $this->get_stat('attachmentcount'), get_formatted_filesize($this->get_stat('attachmentsize'))),
			'ACTIVE_POSTERS'	=> $this->get_stat('activeuserpostcount'),
			'BOARD_STARTDATE'	=> format_short_date($config['board_startdate']),
			'VISIT_IP'			=> $user->ip,

			'TOTAL_USERS'		=> $total_users,
		);

		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('stat');

		// Build stats
		foreach($stats as $stat)
		{
			$template->assign_block_vars('stat', array(
				'IS_CAT'	=> true,
				'S_SEP'		=> $stat['sep'],
				'S_LEGEND'	=> (isset($stat['legend']) ? $user->lang[$stat['legend']] : ''),
			));

			foreach($stat as $lang => $value)
			{
				if($lang == 'legend' || $lang == 'sep')
				{
					continue;
				}

				$template->assign_block_vars('stat', array(
					'IS_CAT'	=> false,

					'S_NAME'	=> $user->lang["ST_$lang"],
					'S_VALUE'	=> $value,
				));
			}
		}

		if($data['user_stats'])
		{
			if(!function_exists('obtain_today_visits'))
			{
				include($this->master->root_path . "includes/functions.$phpEx");
			}
			
			//Grab an array with all the today users info
			$today_users = obtain_today_visits();

			$template->assign_vars(array(
				'SHOW_USER_STATS'			=> true,
				'S_TOTAL_USERS_LASTVISIT'	=> $today_users['lastvisit_users'],
				'S_LASTVISIT_USER_LIST' 	=> $today_users['userlist'],
				'S_NEWEST_USER'				=> get_username_string('full', $config['newest_user_id'], $config['newest_username'], $config['newest_user_colour']),
			));
		}

		$template->assign_var('S_INLINE', (int)$data['stats_inline']);

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$this->display_vars = array(
			'stats_inline'	=> array('lang' => 'STATS_INLINE',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 0),
			'user_stats'	=> array('lang' => 'USER_STATS',	'validate' => 'bool',	'type' => 'radio:yes_no',	'default' => 1),
		);

		return true;
	}

	function get_stat($mode)
	{
		global $db, $user;

		switch($mode)
		{
			case 'newposttotal':
				$sql = 'SELECT COUNT(post_id) AS count_total
					FROM ' . POSTS_TABLE . '
					WHERE post_time > ' . $user->data['session_last_visit'];
			break;

			case 'newtopictotal':
				$sql = 'SELECT COUNT(topic_id) AS count_total
					FROM ' . TOPICS_TABLE . '
					WHERE topic_time > ' . $user->data['session_last_visit'];
			break;
			
			case 'newannouncmenttotal':
				$sql = 'SELECT COUNT(topic_id) AS count_total
					FROM ' . TOPICS_TABLE . '
					WHERE topic_type = ' . POST_ANNOUNCE . '
					AND topic_time > ' . $user->data['session_last_visit'];
			break;

			case 'newstickytotal':
				$sql = 'SELECT COUNT(topic_id) AS count_total
					FROM ' . TOPICS_TABLE . '
					WHERE topic_type = ' . POST_STICKY . '
					AND topic_time > ' . $user->data['session_last_visit'];
			break;	

			case 'announcmenttotal':
				$sql = 'SELECT COUNT(topic_id) AS count_total
					FROM ' . TOPICS_TABLE . '
					WHERE ' . $db->sql_in_set('topic_type', array(POST_ANNOUNCE, POST_GLOBAL));
			break;

			case 'stickytotal':
				$sql = 'SELECT COUNT(topic_id) AS count_total
					FROM ' . TOPICS_TABLE . '
					WHERE topic_type = ' . POST_STICKY;
			break;

			case 'attachmentcount':
				$sql = 'SELECT COUNT(attach_id) as count_total
					FROM ' . ATTACHMENTS_TABLE . '
					WHERE is_orphan = 0';
			break;

			case 'attachmentsize':
				$sql = 'SELECT SUM(filesize) as count_total
					FROM ' . ATTACHMENTS_TABLE . '
					WHERE is_orphan = 0';
			break;

			case 'activeuserpostcount':
				$sql = 'SELECT COUNT(user_id) AS count_total
					FROM ' . USERS_TABLE . '
					WHERE user_posts > 0';
			break;
		}
	
		$result = $db->sql_query($sql);
		$count_total = (int) $db->sql_fetchfield('count_total');
	 	$db->sql_freeresult($result);

		return $count_total;
	}
}
?>
