<?php
/*
*
* @name topic_index_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: topic_index_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class topic_index_block extends blockgets_block
{
	function init($method = '')
	{
		global $phpbb_root_path, $template, $db, $auth, $user, $phpEx;

		$this->tpl_name = 'topic_index_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}
		
		$forum_ids		= array();
		$sql_order		= '';
		$topic_count	= 0;
		
		$start		= request_var('start', 0);
		$first_char = request_var('fchar', '');

		if(empty($data['forums']))
		{
			return false;
		}
		
		foreach($data['forums'] as $forum_id)
		{
			if($auth->acl_get('f_read', $forum_id))
			{
				$forum_ids[] = $forum_id;
			}
		}

		if(!sizeof($forum_ids))
		{
			return true;
		}
		
		$sql_query = 'FROM ' . TOPICS_TABLE . '
			WHERE topic_status <> ' . ITEM_MOVED . '
			AND topic_approved = 1
			AND ' . $db->sql_in_set('forum_id', $forum_ids);
		
		switch($data['sort_mode'])
		{
			case 'topic_title';
				if($first_char)
				{
					$sql_query .= ' AND topic_title ' . $db->sql_like_expression(substr($first_char, 0, 1) . $db->any_char);
				}

				$sql_order = 'ORDER BY LOWER(topic_title) ASC';
			break;
			
			case 'topic_time':
			case 'topic_last_post_time':
				$sql_order = 'ORDER BY ' . $data['sort_mode'] . ' DESC';
			break;
		}
		
		//Delete the array in the template if exists, prevent errors between blocks
		$template->destroy_block_vars('topic');
		
		// Count total of topics
		$sql = "SELECT COUNT(topic_id) AS topic_count $sql_query";
		$result = $db->sql_query($sql);
		$topic_count = (int)$db->sql_fetchfield('topic_count');
		$db->sql_freeresult($result);
		
		$sql = "SELECT forum_id, topic_id, topic_replies, topic_views, topic_time, topic_title,
			topic_poster, topic_first_poster_name, topic_first_poster_colour, topic_last_post_id
			$sql_query
			$sql_order";
		
		if($data['topics_per_page'])
		{
			$result = $db->sql_query_limit($sql, (int)$data['topics_per_page'], $start);
		}
		else
		{
			$result = $db->sql_query($sql);
		}

		while($row = $db->sql_fetchrow($result))
		{
			$row['topic_title'] = censor_text($row['topic_title']);

			$template->assign_block_vars('topic', array(
				'POST_AUTHOR_FULL'		=> get_username_string('full', $row['topic_poster'], $row['topic_first_poster_name'], $row['topic_first_poster_colour']),

				'REPLIES'         		=> $row['topic_replies'],
				'TOPIC_VIEWS'      		=> $row['topic_views'],
				'TOPIC_TIME'   			=> $user->format_date($row['topic_time']),
				'U_LAST_COMMENTS'   	=> append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;p=' . $row['topic_last_post_id'] . '#p' . $row['topic_last_post_id']),

				'MINI_POST_IMG'      	=> $user->img('icon_post_target', 'POST'),
				'TITLE'             	=> truncate_string($row['topic_title'], $data['title_limit'], 255, false, '...'),
				'FULL_TITLE'      		=> str_replace('&quot;', "'", $row['topic_title']),
				'U_VIEW_TOPIC'      	=> append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'f=' . $row['forum_id'] . '&amp;t=' . $row['topic_id']),
			));
		}
		$db->sql_freeresult($result);
		
		if($data['char_select'])
		{
			$first_characters = array('' => $user->lang['CHAR_ALL']);

			for($i = 97; $i < 123; $i++)
			{
				$first_characters[chr($i)] = chr($i - 32);
			}

			foreach($first_characters as $char => $desc)
			{
				$template->assign_block_vars('first_char', array(
					'DESC'			=> $desc,
					'VALUE'			=> $char,
					'S_SELECTED'	=> ($first_char == $char) ? true : false,
					'U_SORT'		=> '#?' . $char,
				));
			}
		}
		
		$template->assign_vars(array(
			'BLOCK_PAGINATION'		=> ($data['topics_per_page']) ? generate_pagination('#', $topic_count, $data['topics_per_page'], $start) : '',
			'BLOCK_PAGE_NUMBER'		=> on_page($topic_count, $data['topics_per_page'], $start),
			'S_ADVANCED_DISPLAY'	=> ($this->config['autofit'] || $data['only_title']) ? false : true,
			'S_SHORT_MODE'			=> $this->config['autofit'],
			'S_AJAX'				=> ($method != '') ? true : false,
			'S_CHAR_SELECT'			=> ($data['sort_mode'] == 'topic_title' && $data['char_select']) ? true : false,
			'S_FIRST_CHAR'			=> $first_char,
			
			'U_ACTION'				=> $this->master->get_board_path('page'),
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				if($submit)
				{
					$new['forums'] = request_var('forums', array(0));
				}
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$sort_options = array(
			'topic_title'			=> 'TOPIC_TITLE',
			'topic_time'			=> 'TOPIC_TIME',
			'topic_last_post_time'	=> 'LAST_POST_TIME',
		);

		$this->display_vars = array(
			'forums'			=> array('lang' => 'FORUMS',				'type' => 'custom',			'function' => 'blg_forums_select',	'params' => array('forums', '{CONFIG_VALUE}', 1)),
			'topics_per_page'	=> array('lang' => 'TINDEX_PER_PAGE',		'validate' => 'int:0:1000',	'type' => 'text:4:3',	'default' => 25),
			'sort_mode'			=> array('lang' => 'TINDEX_SORT_MODE',		'valitate' => 'string',		'type' => 'select',		'function' => 'blg_make_select',	'params' => array($sort_options, '{CONFIG_VALUE}'),	'default' => 'topic_title'),
			'title_limit'		=> array('lang' => 'TITLE_LIMIT',			'validate' => 'int:1:255',	'type' => 'text:4:3',	'default' => 50),
			'only_title'		=> array('lang' => 'TINDEX_ONLY_TITLE',		'validate' => 'bool',		'type' => 'radio:yes_no',	'default' => 0),
			'char_select'		=> array('lang' => 'TINDEX_CHAR_SELECT',	'validate' => 'bool',		'type' => 'radio:yes_no',	'default' => 1),
		);

		return true;
	}
}
?>
