<?php
/*
*
* @name whos_online_block.php
* @package phpBB3 cBB Blockgets
* @version $Id: whos_online_block.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

class whos_online_block extends blockgets_block
{
	function init()
	{
		global $phpbb_root_path, $template, $db, $auth, $config, $user, $phpEx;

		$this->tpl_name = 'whos_online_block';

		if(($data = $this->unserialize()) === false)
		{
			return false;
		}
		
		if(!function_exists('obtain_today_visits'))
		{
			include($this->master->root_path . "includes/functions.$phpEx");
		}

		//Grab an array with all the today users info
		$today_users = obtain_today_visits();
		
		// Force simple view
		if($this->config['autofit'])
		{
			$data['advanced'] = false;
		}

		if($data['advanced'])
		{
			// If online users don't load with page_header, load it
			if(empty($template->_tpldata['.'][0]['TOTAL_USERS_ONLINE']))
			{
				$l_online_users = $online_userlist = $l_online_record = $l_online_time = '';

				if ($config['load_online'] && $config['load_online_time'])
				{
					$online_users			= obtain_users_online(0, 'forum');
					$user_online_strings	= obtain_users_online_string($online_users, 0, 'forum');

					$l_online_users		= $user_online_strings['l_online_users'];
					$online_userlist	= $user_online_strings['online_userlist'];
					$total_online_users	= $online_users['total_online'];

					$l_online_record = $user->lang('RECORD_ONLINE_USERS', $config['record_online_users'], $user->format_date($config['record_online_date'], false, true));

					$l_online_time = ($config['load_online_time'] == 1) ? 'VIEW_ONLINE_TIME' : 'VIEW_ONLINE_TIMES';
					$l_online_time = $user->lang($l_online_time, $config['load_online_time']);
				}

				$template->assign_vars(array(
					'TOTAL_USERS_ONLINE'		=> $l_online_users,
					'LOGGED_IN_USER_LIST'		=> $online_userlist,
					'RECORD_USERS'				=> $l_online_record,
					
					'L_ONLINE_EXPLAIN'			=> $l_online_time,
				));
			}
			
			// Grab group details for legend display
			if ($auth->acl_gets('a_group', 'a_groupadd', 'a_groupdel'))
			{
				$sql = 'SELECT group_id, group_name, group_colour, group_type
					FROM ' . GROUPS_TABLE . '
					WHERE group_legend = 1
					ORDER BY group_name ASC';
			}
			else
			{
				$sql = 'SELECT g.group_id, g.group_name, g.group_colour, g.group_type
					FROM ' . GROUPS_TABLE . ' g
					LEFT JOIN ' . USER_GROUP_TABLE . ' ug
						ON (
							g.group_id = ug.group_id
							AND ug.user_id = ' . $user->data['user_id'] . '
							AND ug.user_pending = 0
						)
					WHERE g.group_legend = 1
						AND (g.group_type <> ' . GROUP_HIDDEN . ' OR ug.user_id = ' . $user->data['user_id'] . ')
					ORDER BY g.group_name ASC';
			}
			$result = $db->sql_query($sql);

			$legend = array();
			while ($row = $db->sql_fetchrow($result))
			{
				$colour_text = ($row['group_colour']) ? ' style="color:#' . $row['group_colour'] . '"' : '';
				$group_name = ($row['group_type'] == GROUP_SPECIAL) ? $user->lang['G_' . $row['group_name']] : $row['group_name'];

				if ($row['group_name'] == 'BOTS' || ($user->data['user_id'] != ANONYMOUS && !$auth->acl_get('u_viewprofile')))
				{
					$legend[] = '<span' . $colour_text . '>' . $group_name . '</span>';
				}
				else
				{
					$legend[] = '<a' . $colour_text . ' href="' . append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=group&amp;g=' . $row['group_id']) . '">' . $group_name . '</a>';
				}
			}
			$db->sql_freeresult($result);

			$template->assign_vars(array(
				'S_TOTAL_USERS_LASTVISIT'	=> $today_users['lastvisit_users'],
				'S_LASTVISIT_USER_LIST'		=> $today_users['userlist'],
				'S_LEGEND'					=> implode(', ', $legend),
			));
		}
		else
		{
			$online_users = obtain_users_online(0, 'forum');

			$template->assign_vars(array(
				'S_TOTAL_ONLINE'	=> $online_users['total_online'],
				'S_VISIBLE_ONLINE'	=> $online_users['visible_online'],
				'S_HIDDEN_ONLINE'	=> $online_users['hidden_online'],
				'S_GUEST_ONLINE'	=> $online_users['guests_online'],

				'S_TOTAL_LASTDAY'	=> $today_users['total_today'],
				'S_VISIBLE_LASTDAY'	=> $today_users['visible_today'],
				'S_HIDDEN_LASTDAY'	=> $today_users['hidden_today'],
				'S_GUEST_LASTDAY'	=> $today_users['guests_today'],
			));
		}

		$template->assign_vars(array(
			'S_ADVANCED_MODE'	=> $data['advanced'],
			'S_WIO_USERS'		=> $data['usernames'],
		));

		unset($data);
		return true;
	}

	function configure($mode, $block_row, &$new, &$submit)
	{
		switch($mode)
		{
			case 'validate':
				$new = $this->unserialize($block_row['block_content'], true, $new);
			break;

			case 'submit':
				$new['block_content'] = $this->serialize($new);
			break;
		}
	}

	function get_config()
	{
		$this->display_vars = array(
			'advanced'		=> array('lang' => 'WHOS_ADVANCED',		'validate' => 'bool',	'type' => 'radio:yes_no', 'default' => 1),
			'usernames'		=> array('lang' => 'WHOS_USERNAMES',	'validate' => 'bool',	'type' => 'radio:yes_no', 'default' => 1),
		);

		return true;
	}
}
?>
