<?php
/*
*
* @name functions.php
* @package phpBB3 cBB Blockgets
* @version $Id: functions.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
 * obtain_today_visits
 * Queries the session table to get information about today visits
 *
 * @return array An array containing the ids of today visits, hidden and visible users, as well as statistical info
*/
function obtain_today_visits()
{
	global $phpbb_root_path, $db, $config, $user, $auth, $phpEx;

	$user_list = array();

	$today_users = array(
		'lastvisit_users'	=> '',
		'userlist'			=> '',
		'total_today'		=> 0,
		'visible_today'		=> 0,
		'hidden_today'		=> 0,
		'guests_today'		=> 0,

		'hidden_online'		=> 0,
	);

	//Get the last visit guests
	$sql = 'SELECT COUNT(DISTINCT s.session_ip) as guest_count
		FROM ' . SESSIONS_TABLE . ' s
		WHERE s.session_user_id = ' . ANONYMOUS . '
		AND s.session_last_visit > ' . strtotime('-1 day');
	$result = $db->sql_query($sql);
	$today_users['guests_today'] = $db->sql_fetchfield('guest_count');
	$db->sql_freeresult($result);

	// Get the last visit users
	$sql = 'SELECT username, username_clean, user_id, user_type, user_allow_viewonline, user_colour, user_lastvisit
		FROM ' . USERS_TABLE . '
		WHERE user_lastvisit > ' . strtotime('-1 day') . '
		AND user_id <> ' . ANONYMOUS . '
		ORDER BY username_clean ASC';
	$result = $db->sql_query($sql, 600); //cache the sql during 10 minutes

	while($row = $db->sql_fetchrow($result))
	{
		if ($row['user_allow_viewonline'])
		{
			$today_users['visible_today']++;
		}
		else
		{
			$row['username'] = '<em>' . $row['username'] . '</em>';
			$today_users['hidden_online']++;
		}

		if($row['user_allow_viewonline'] || $auth->acl_get('u_viewonline'))
		{
			$user_list[] = get_username_string(($row['user_type'] <> USER_IGNORE) ? 'full' : 'no_profile', $row['user_id'], $row['username'], $row['user_colour']);
		}
	}
	$db->sql_freeresult($result);

	if(!empty($user_list))
	{
		$today_users['userlist'] = $user->lang['REGISTERED_USERS'] . ' ' . implode(', ', $user_list);
	}
	unset($user_list);

	$today_users['total_today'] = $today_users['guests_today'] + $today_users['visible_today'] + $today_users['hidden_today'];

	// Build online listing
	$vars_lastvisit = array(
		'LASTVISIT'	=> 'total_today',
		'REG'		=> 'visible_today',
		'HIDDEN'	=> 'hidden_today',
		'GUEST'		=> 'guests_today',
	);

	foreach($vars_lastvisit as $v_prefix => $var)
	{
		$today_users['lastvisit_users'] .= $user->lang($v_prefix . (($today_users[$var] == 1) ? '_VISIT_TOTAL' : '_VISITS_TOTAL'), $today_users[$var]);
	}
	unset($vars_lastvisit);

	return $today_users;
}

?>