<?php
/*
*
* @name functions_acp.php
* @package phpBB3 cBB Blockgets
* @version $Id: functions_acp.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
 * blg_groups_select
 * Create a select with all groups
*/
function blg_groups_select($config_key, $select_groups, $is_config = true, $include_all = true)
{
	global $db, $user;

	$output = '';
	$group_ary = array();

	if(!empty($select_groups))
	{
		$group_ary = (is_array($select_groups) ? $select_groups : explode(',', $select_groups));
	}

	// Get all the groups
	$sql = 'SELECT DISTINCT group_type, group_name, group_id
		FROM ' . GROUPS_TABLE . '
		ORDER BY group_type DESC, group_name ASC';
	$result = $db->sql_query($sql);

	$output = '<select style="width: 100%;" name="' . $config_key . '[]" id="' . $config_key . '" multiple="multiple" size="5"' .
		(($include_all) ? ' onchange="groups_change(this, 1)"' : '') . '>';

	while($row = $db->sql_fetchrow($result))
	{
		$s_selected = (in_array($row['group_id'], $group_ary)) ? ' selected="selected"' : '';
		$output .= '<option' . (($row['group_type'] == GROUP_SPECIAL) ? ' class="sep"' : '') . ' value="' . $row['group_id'] . '"' . $s_selected . '>' . (($row['group_type'] == GROUP_SPECIAL) ? $user->lang['G_' . $row['group_name']] : $row['group_name']) . '</option>';
	}
	$db->sql_freeresult($result);

	$output .= '</select>';

	if($include_all)
	{
		$output .= '<br/><label><input type="checkbox" class="radio" name="all_groups" onclick="groups_change(this, 2)" value="1"' . (($select_groups == 'all' || isset($_POST['all_groups'])) ? ' checked="checked"' : '') . '/> ' . $user->lang['ALL_GROUPS'] . '</label>';
	}

	return $output;
}

/**
 * blg_img_template
 * Create a select with actual img and new img request
*/
function blg_img_template($form, $key, $type = '', $item = '', $action = 'view_icons', $label = 'IMAGE')
{
	global $phpbb_admin_path, $user, $phpEx, $blockgets;

	switch($action)
	{
		case 'view_banners':
			$path = $blockgets->path . 'images/banners/';
			$default_image = 'no_image.gif';
		break;

		case 'view_icons':
		default:
			$path = $blockgets->path . 'images/icons/';
			$default_image = 'small/blank.gif';
		break;
	}

	switch($type)
	{
		case 'current':
			if(!$item)
			{
				$item = $default_image;
			}

			$item_img_url = $item;
			build_img_path($item_img_url, $path);

			$text = '<img id="' . $key . '" src="' . $item_img_url . '" />
				<input type="hidden" name="config[' . $key . ']" value="' . $item . '" />';
		break;

		case 'new':
			$u_action = append_sid("{$phpbb_admin_path}index.$phpEx?i=blockgets&amp;mode=config&amp;action=$action&amp;f=$form&amp;k=$key");

			$text = '<div id="new_img_container">
				<img id="' . $key . '" src="" /><input type="hidden" name="' . $key . '" value="" /><br />
				<a class="blg-button small" href="#" onclick="delete_new_image(this); return false;">' . $user->lang["DELETE_$label"] . '</a>
				</div><a class="blg-button small" href="' . $u_action . '" onclick="popup(this.href, 700, 550, \'_blg_icons\'); return false;">' . $user->lang["SELECT_$label"] . '</a>';
		break;

		default:
			$text = '';
		break;
	}

	return $text;
}

/**
 * blg_forums_select
 * Make select with the forum names
*/
function blg_forums_select($config_key = 'forums', $select_ids = false, $ignore_cats = false)
{
	$output = '<select style="width: 100%;" name="' . $config_key . '[]" id="' . $config_key . '" multiple="multiple" size="5">';
	$output .= (($ignore_cats) ? make_forum_select($select_ids, false, true, true, true, true) : make_forum_select($select_ids, false, true));
	$output .= '</select>';

	return $output;
}

/**
 * blg_lists_select
 * Make select with the lists for menus/banners
*/
function blg_lists_select($key, $list_type = '', $select_id = 0)
{
	global $db, $user, $phpbb_admin_path, $phpEx;

	$sql = 'SELECT list_id, list_name
		FROM ' . BLG_LISTS_TABLE . "
		WHERE list_type = '$list_type'
		ORDER BY list_name ASC";
	$result = $db->sql_query($sql);

	$options = array();
	while($row = $db->sql_fetchrow($result))
	{
		$options[$row['list_id']] = $row['list_name'];
	}
	$db->sql_freeresult($result);

	$output = '<select name="config[' . $key . ']">';
	$output .= blg_make_select($options, $select_id, false, 'NO_LISTS');
	$output .= '<select>';
	
	$output .= '&nbsp' . $user->lang('LIST_MANAGE', append_sid("{$phpbb_admin_path}index.$phpEx?i=blockgets_lists&mode=$list_type"));
	
	return $output;
}

/**
 * banner_listtype_select
 * Make select with banner types
*/
function banner_listtype_select($select_id = -1)
{
	$types = array(
		BLG_NO_SCROLL 	=> 'LIST_NO_SCROLL',
		BLG_SCROLL_H	=> 'LIST_SCROLL_H',
		BLG_SCROLL_V	=> 'LIST_SCROLL_V',
	);

	return blg_make_select($types, $select_id);
}

/**
 * make_scroll_select
 * Make selects with scroller options
*/
function make_scroll_select($item = '', $list = '')
{
	global $user;

	$lists = array(
		'direction'		=> array('left', 'right', 'up', 'down'),
		'direction_x'	=> array('left', 'right'),
		'align'			=> array('left', 'center', 'right'),
	);

	if(!isset($lists[$list]))
	{
		return '';
	}

	$options = array();
	foreach($lists[$list] as $id)
	{
		$options[$id] =  $user->lang[strtoupper($id)];
	}

	return blg_make_select($options, $item);
}

/**
 * build_share_select
 * Make select for a share block
*/
function build_share_select($type, $select, $buttons = false)
{
	switch($type)
	{
		case 'sizes':
			$sizes	= array('small' => 'SHARE_SMALL',	'medium' => 'SHARE_MEDIUM',	'big' => 'SHARE_BIG');
			return blg_make_select($sizes, $select);
		break;

		case 'buttons':
			$string = '';

			if(!is_array($select))
			{
				$select = array();
			}

			foreach($buttons as $name => $params)
			{
				$selected = (in_array($params['id'], $select) ? ' checked="checked"' : '');
				$string .= '<label><input type="checkbox" class="radio" name="button[]" value="' . $params['id'] . '"' . $selected . '> ' . ucfirst($name) . '</label>';
			}

			return $string;
		break;
	}

	return '';
}

/**
 * blg_make_select
 * Build select input for blocks config
*/
function blg_make_select($options, $select = false, $parse_lang = true, $empty_label = false)
{
	global $user;

	$string = '';
	
	$in_group = false;

	foreach($options as $value => $lang)
	{
		$title		= (($parse_lang && isset($user->lang[$lang])) ? $user->lang[$lang] : $lang);

		if(strpos($value, 'legend') !== false)
		{
			$string .= (($in_group) ? '</optgroup>' : '') . '<optgroup label="' . $title . '">';
			$in_group = true;
			
			continue;
		}

		$selected	= (($value == $select) ? ' selected="selected"' : '');
		$string .= '<option value="' . $value . '"' . $selected . '>' . $title . '</option>';
	}
	
	if($in_group)
	{
		$string .= '</optgroup>';
	}
	
	if(!$string && $empty_label !== false)
	{
		$string = '<option value="0">' . (isset($user->lang[$empty_label]) ? $user->lang[$empty_label] : $empty_label) . '</option>';
	}

	return $string;
}

/**
 * blg_build_list
 * Make the structure to the jQuery list
*/
function blg_build_list($id, $name, $list_items = false, $dialog_items = false)
{
	global $user;

	return '<script type="text/javascript">
	// <![CDATA[
		jblockgets(function($) {
			$("#' . $id . '").sortable_list({
				name : "' . $name . '"
			});
		});
	// ]]>
	</script>

	<div id="' . $id . '">
		<div class="container">' . (is_array($list_items) ? build_hidden_fields(array($name	=> $list_items)) : '') . '</div>
		<div class="dialog-items" style="display:none;">' . (($dialog_items) ? _build_dialog_items($dialog_items) : '') . '</div>
	</div>';
}

/**
 * _build_dialog_items
 * Internal function to make all the jQuery dialog items for "blg_build_list"
*/
function _build_dialog_items($rows)
{
	global $user;

	if(!is_array($rows))
	{
		return '';
	}
	
	$json = '';
	
	foreach($rows as $id => $row)
	{
		$title		= (isset($user->lang[$row[0]]) ? $user->lang[$row[0]] : $row[0]);
		$explain	= (isset($user->lang[$row[0] . '_EXPLAIN']) ? $user->lang[$row[0] . '_EXPLAIN'] : '');
		$rexexp		= (isset($row[1]) ? implode(',', $row[1]) : '');

		$json .= (($json) ? ', ' : '') . $id . ":['$title', '$explain'" . (($rexexp) ? ", [$rexexp]" : '') . ']';
	}
	
	return '{' . $json . '}';
}

/**
 * blg_build_editor
 * Make a Textarea with "Full Editor" button
*/
function blg_build_editor($text, $form_id, $key, $rows, $cols)
{
	global $user, $phpbb_admin_path, $phpEx;

	$u_action = append_sid("{$phpbb_admin_path}index.$phpEx?i=blockgets&amp;mode=config&amp;action=editor&amp;f=$form_id&amp;k=$key");

	$text = '<textarea id="' . $key . '" name="config[' . $key . ']" cols="' . $cols . '" rows="' . $rows . '" style="width:98%;">' . $text . '</textarea>';
	
	$text .= '<p class="quick"><a href="' . $u_action . '" onclick="popup(this.href, 700, 550, \'_blg_editor\'); return false;" class="blg-button">' . $user->lang['BLG_FULL_EDITOR'] . '</a></p>';

	return $text;
}

/**
 * blg_counter_rst
 * Make a button for global and local counter reset
*/
function blg_counter_rst($form_id = '')
{
	global $user;
	
	$btn = '<input class="blg-button small" name="counter_reset" value="' . $user->lang['RUN'] . '" ';
	
	if($form_id)
	{
		$btn .= 'type="button" onclick="jblockgets.counter_reset(\'' . $form_id . '\');" />';
	}
	else
	{
		$btn .= 'type="submit"';
	}
	
	return $btn;
}
?>
