<?php
/**
*
* @package install_install.php
* @package cBB Blockgets Installer
* @version $Id: install_install.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
*/
if(!defined('IN_PHPBB') || !defined('IN_INSTALL'))
{
	exit;
}

/**
* Installation
* @package install
*/
class install_portal_importer extends installer
{
	var $subs = array('requirements', 'import', 'final');

	function main()
	{
		global $user, $phpbb_root_path, $phpEx;

		switch ($this->sub)
		{
			case 'requirements':
				$this->page_title = 'REQUIREMENTS';
				$this->check_requirements();
				
				$this->assign_vars('BODY', array('IMPORT_INTRO_BODY', $this->mod_title));
			break;
			
			case 'import':
				$this->page_title = 'IMPORT';

				$checks = array(
					array('legend1',	'IMPORT_RESULTS'),

					array('DATABASE',		false, $this->portal_import()),
				);
				
				// Check if and error occurs
				if($this->build_checks($checks, 'IMPORT'))
				{
					$this->buttons['_final'] = 'NEXT_STEP';
				}
			break;

			case 'final':
				$this->page_title = 'INSTALL_CONGRATS';

				// clear cache
				$this->umil->cache_purge();

				$this->assign_vars(array(
					'BODY_TITLE'	=> 'IMPORT_CONGRATS',
					'S_NOTICE'		=> array('IMPORT_CONGRATS_EXPLAIN', $this->mod_title, $this->new_version),
				));
				
				$this->buttons['link2'] = array('LOGIN', append_sid($phpbb_root_path . 'adm/index.' . $phpEx, 'i=blockgets&amp;mode=config', true, $user->session_id));
			break;
		}

		$this->assign_vars('S_TITLE', 'IMPORT');
	}

	/**
	* Checks that the server we are installing on meets the requirements for running cBB Blockgets
	*/
	function check_requirements()
	{
		global $phpbb_root_path, $db, $config, $phpEx, $table_prefix;
		
		$neccessary_portal_version = '1.0.1';
		
		$checks = array();

		$passed = array('portal_installed' => false, 'blg_installed' => false);

		$checks[] = array('legend1', 'REQUIRED_CHECKS');
		
		// Check the mod (cBB Portal)
		if(defined('PORTAL_CONFIG_TABLE') && $this->umil->table_exists(PORTAL_CONFIG_TABLE))
		{
			$sql = 'SELECT config_value AS version
				FROM ' . PORTAL_CONFIG_TABLE . '
				WHERE config_name = "portal_version"';
			$result = $db->sql_query($sql);
			$portal_version = $db->sql_fetchfield('version');
			$db->sql_freeresult($result);
			
			$passed['portal_installed'] = version_compare($portal_version, $neccessary_portal_version, '==');
		}

		// Check the mod (cBB Blockgets)
		if(!empty($config['blg_version']))
		{
			$passed['blg_installed'] = version_compare($config['blg_version'], $this->new_version, '==');
		}

		$checks[] = array('PORTAL_INSTALLED', $neccessary_portal_version, $passed['portal_installed']);
		$checks[] = array('BLG_INSTALLED', $this->new_version, $passed['blg_installed']);

		$this->build_checks($checks);
		
		if(in_array(false, $passed))
		{
			$this->buttons['_requirements'] = 'TRY_AGAIN';
			$this->assign_vars('S_ERROR', 'REQ_IMPORT_ERROR');
		}
		else
		{
			$this->buttons['_import'] = 'IMPORT_START';
			$this->assign_vars('S_NOTICE', 'REQ_IMPORT_NOTICE');
		}
	}
	
	function portal_import()
	{
		global $db, $phpbb_root_path, $phpEx;

		// Import configuration
		$portal_config = array();
		$config_convert = array(
			'portal_enabled'		=> 'blg_enabled',
			'portal_on_board'		=> 'blg_on_board',
			'portal_as_principal'	=> 'blg_home_as_principal',
			'collapse_blocks'		=> 'blg_collapse_blocks',
			'resize_enabled'		=> 'blg_resize_enabled',
			'image_max_width'		=> 'blg_image_max_width',
			'counter_start_date'	=> 'blg_counter_start_date',
			'counter_interval'		=> 'blg_counter_interval',
			'counter_visit_count'	=> 'blg_counter_visit_count',
		);
		
		$sql = 'SELECT *
			FROM ' . PORTAL_CONFIG_TABLE;
		$result = $db->sql_query($sql);
		while($row = $db->sql_fetchrow($result))
		{
			$portal_config[$row['config_name']] = $row['config_value'];
		}
		$db->sql_freeresult($result);
		
		foreach($config_convert as $portal_id => $blg_id)
		{
			if(isset($portal_config[$portal_id]))
			{
				$config_convert[$blg_id] = $portal_config[$portal_id];
			}
			
			unset($config_convert[$portal_id]);
		}
		
		if(!empty($config_convert))
		{
			foreach($config_convert as $key => $value)
			{
				$sql = 'UPDATE ' . CONFIG_TABLE . "
					SET config_value = '" . $db->sql_escape($value) . "'
					where config_name = '$key'";
				$db->sql_query($sql);
			}
		}
		
		unset($config_convert);
		
		// Import blocks and pages
		$portal_blocks = $blg_blocks = $blg_pages = array();
		
		$old_column_styles = array(
			1	=> array(5, 7, 8), 	// left column
			2	=> array(2, 8),		// center column
			3	=> array(5, 7, 8),	// right column
			4	=> array(3, 6, 7),	// top column
			5	=> array(4, 6, 7),	// bottom column
		);
		
		// Get the pages from blockgets
		$sql = 'SELECT page_id, page_alias, left_column_width, right_column_width
			FROM ' . BLG_PAGES_TABLE;
		$result = $db->sql_query($sql);
		while($row = $db->sql_fetchrow($result))
		{
			// equivalence
			if($row['page_alias'] == 'home')
			{
				$row['page_alias'] = 'portal';
			}
			
			$blg_pages[$row['page_alias']] = $row['page_id'];
		}
		$db->sql_freeresult($result);
		
		$sql = 'SELECT *
			FROM ' . PORTAL_BLOCK_TABLE . '
			ORDER BY block_position, block_order';
		$result = $db->sql_query($sql);
		while($row = $db->sql_fetchrow($result))
		{
			$block_page = $row['block_page'];
			
			// Disable addons because not compatibles with cBB Blockgets
			if(strpos($row['block_alias'], '_addon') !== false)
			{
				continue;
			}
			
			if(!isset($portal_blocks[$block_page]))
			{
				$portal_blocks[$block_page] = array();
			}
			
			$portal_blocks[$block_page][] = $row;
		}
		$db->sql_freeresult($result);
		
		if(!empty($portal_blocks))
		{
			// Include block class from blockgets
			if(!class_exists('blockgets_block'))
			{
				include($phpbb_root_path . 'blockgets/blockgets.' . $phpEx);
			}
			
			foreach($portal_blocks as $block_page => $rows)
			{
				foreach($rows as $row)
				{
					$block_id = $row['block_id'];
					$block_alias = $row['block_alias'];
					$block_position = $row['block_position'];

					$page_id = (isset($blg_pages[$block_page]['page_id']) ? $blg_pages[$block_page]['page_id'] : 0);
					$old_column_style = (!empty($portal_config[$block_page . '_column_style']) ? $portal_config[$block_page . '_column_style'] : 0);
					
					if($block_alias == 'forum_content')
					{
						$blg_blocks[] = array(
							'block_title'		=> 'FORUM',
							'block_content'		=> '',
							'block_alias'		=> $block_alias,
							'block_img'			=> '',
							'block_order'		=> $row['block_order'],
							'block_position'	=> $row['block_position'],
							'block_page'		=> $page_id,
							'block_enabled'		=> $row['block_enabled'],
							'block_groups'		=> $row['block_groups'],
							'block_style'		=> (in_array($old_column_style, $old_column_styles[$block_position]) ? BLOCK_STYLE_ALTERNATIVE : BLOCK_STYLE_DEFAULT),
							'allow_collapse'	=> $portal_config['collapse_blocks'],
							'bbcode_bitfield'	=> '',
							'bbcode_uid'		=> '',
						);
						
						continue;
					}
					
					$block_content = $bbcode_uid = $bbcode_bitfield = '';
					
					// Find bbcode_uid and bbcode_bitfield in portal's configuration
					$find_ids = array("$block_id", "guest_$block_id", "member_$block_id");
					
					foreach($find_ids as $id)
					{
						$uid_id = 'bb_uid_' . $id;
						$bitfield_id = 'bb_bitfield_' . $id;
						
						if(isset($portal_config[$uid_id]))
						{
							$bbcode_uid = $portal_config[$uid_id];
							$bbcode_bitfield = $bbcode_bitfield | base64_decode($portal_config[$bitfield_id]);
						}
					}
					
					// Apply the block content with the new configuration
					$blg_block_filename = $phpbb_root_path . 'blockgets/block/' . $block_alias . ".$phpEx";
					
					if(!$page_id || !file_exists($blg_block_filename))
					{
						continue;
					}
					
					$old_unserialize = @unserialize($row['block_content']);
					$new_data = array();
					
					// In welcome_block, adjust the bbcodes
					if($bbcode_bitfield && $block_alias == 'welcome_block')
					{
						$regexp = '#\[(\/?[a-z0-9\*\+\-]+(?:=(?:&quot;.*&quot;|[^\]]*))?(?::[a-z])?)(?\:([0-9a-z]{5,}))\]#s';
						
						$old_unserialze['guest_text'] = preg_replace($regexp, '[\\1:' . $bbcode_uid . ']', $old_unserialze['guest_text']);
						$old_unserialze['member_text'] = preg_replace($regexp, '[\\1:' . $bbcode_uid . ']', $old_unserialze['member_text']);
					}
					
					if(!empty($old_unserialize) && is_array($old_unserialize))
					{
						if(!class_exists($block_alias))
						{
							include($blg_block_filename);
						}
						
						$block_class = new $block_alias();
						
						$has_config = $block_class->get_config();
						
						if($has_config && !empty($block_class->display_vars))
						{
							foreach($block_class->display_vars as $var_id => $data)
							{
								if(isset($old_unserialize[$var_id]))
								{
									$new_data[$var_id] = $this->_replace($old_unserialize[$var_id]);
								}
								else if(isset($data['default']))
								{
									$new_data[$var_id] = $data['default'];
								}
								else
								{
									$new_data[$var_id] = '';
								}
							}
						}
					}
					
					$blg_blocks[] = array(
						'block_title'		=> $row['block_title'],
						'block_content'		=> (sizeof($new_data) ? serialize($new_data) : $row['block_content']),
						'block_alias'		=> $row['block_alias'],
						'block_img'			=> $row['block_img'],
						'block_order'		=> $row['block_order'],
						'block_position'	=> $row['block_position'],
						'block_page'		=> $page_id,
						'block_enabled'		=> $row['block_enabled'],
						'block_groups'		=> $row['block_groups'],
						'block_style'		=> (in_array($old_column_style, $old_column_styles[$block_position]) ? BLOCK_STYLE_ALTERNATIVE : BLOCK_STYLE_DEFAULT),
						'allow_collapse'	=> $portal_config['collapse_blocks'],
						'bbcode_bitfield'	=> $bbcode_uid,
						'bbcode_uid'		=> $bbcode_bitfield,
					);
				}
			}
			
			if(sizeof($blg_blocks))
			{
				// Delete all blocks from cBB Blockgets
				$db->sql_query('TRUNCATE TABLE ' . BLG_BLOCK_TABLE);
				
				// Insert the cBB Portal blocks into cBB Blockgets
				$db->sql_multi_insert(BLG_BLOCK_TABLE, $blg_blocks);
			}
		}
		
		// Apply new configuration to columns
		foreach($blg_pages as $page_alias => $page_data)
		{
			$left_width 	= (isset($portal_config[$page_alias . '_left_column']) ? $portal_config[$page_alias . '_left_column'] : false);
			$right_width	= (isset($portal_config[$page_alias . '_right_column']) ? $portal_config[$page_alias . '_right_column'] : false);
		
			if($left_width === false && $right_width === false)
			{
				continue;
			}
			
			$sql_ary = array(
				'left_column_width'		=> ($left_width !== false) ? $left_width : $page_data['left_column_width'],
				'right_column_width'	=> ($right_width !== false) ? $right_width : $page_data['right_column_width'],
			);
			
			$sql = 'UPDATE ' . BLG_PAGES_TABLE . '
				SET ' . $db->sql_build_array('UPDATE', $sql_ary) . '
				WHERE page_id = ' . $page_data['page_id'];
			$db->sql_query($sql);
		}
		
		// Import the calendar events (copy the table directly)
		$this->_copy_table(PORTAL_EVENTS_TABLE, BLG_EVENTS_TABLE, 'event_id');

		// Import the lists (copy the tables directly)
		$this->_copy_table(PORTAL_LISTS_TABLE, BLG_LISTS_TABLE, 'list_id');
		$this->_copy_table(PORTAL_LISTS_DATA_TABLE, BLG_LISTS_DATA_TABLE, 'link_id');
		
		return true;
	}
	
	function _copy_table($from_table, $to_table, $primary_key)
	{
		global $db;

		$copy_rows = array();
		$sql = "SELECT *
			FROM $from_table
			ORDER BY $primary_key";
		$result = $db->sql_query($sql);
		while($row = $db->sql_fetchrow($result))
		{
			// Not set the autoincrement values
			unset($row[$primary_key]);

			$copy_rows[] = $row;
		}
		$db->sql_freeresult($result);
		
		if(sizeof($copy_rows))
		{
			$db->sql_query('TRUNCATE TABLE ' . $to_table);
			$db->sql_multi_insert($to_table, $copy_rows);
		}
	}
	
	function _replace($text)
	{
		$replaces = array(
			'portal-banner.gif'		=> 'canidev-banner.png',
			'{T_PORTAL_PATH}'		=> '{T_BLOCKGETS_PATH}',
			'cbb-portal-logo.png'	=> 'cbb-blockgets-logo.png',
		);
		
		$text = str_replace(array_keys($replaces), array_values($replaces), $text);
		
		return $text;
	}
}
?>