<?php
/*
*
* @name player.php
* @package phpBB3 cBB Blockgets
* @version $Id: player.php,v1.0.3 01/11/2012 $
*
* @copyright (c) 2012 CaniDev
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/

if(!defined('IN_PHPBB'))
{
	define('IN_PHPBB', true);
	$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : '../';
	$phpEx = substr(strrchr(__FILE__, '.'), 1);
	include($phpbb_root_path . 'common.' . $phpEx);
	
	// Start session management
	$user->session_begin();
	$auth->acl($user->data);
	$user->setup();
	
	if(empty($blockgets->enabled))
	{
		exit;
	}
	
	$block_id = request_var('id', 0);

	$sql = 'SELECT block_content
		FROM ' . BLG_BLOCK_TABLE . "
		WHERE block_id = $block_id";
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);
	$db->sql_freeresult($result);
	
	if(!$row ||($data = blockgets_block::unserialize($row['block_content'])) === false)
	{
		trigger_error('NO_TRACKLIST');
	}
	
	$data['autoplay'] = request_var('autoplay', $data['autoplay']);
	
	create_player($data, $block_id, true);
	
	page_header($user->lang['PLAYER']);
	
	$template->set_filenames(array(
		'body' => $blockgets->path . 'block/player_block.html'
	));
	
	page_footer();

	unset($data);
}

function create_player($data, $block_id, $in_window = false)
{
	global $template, $phpbb_root_path, $phpEx, $blockgets;

	$template->assign_vars(array(
		'S_IN_WINDOW'	=> $in_window,
		'S_AUTOPLAY'	=> ($data['autoplay']) ? true : false,
		'S_PLAYLIST'	=> $data['playlist'],
		
		'U_FLASHPLAYER_URL'	=> $blockgets->root_path . 'swf/player.swf',
		'U_PLAYER_URL'		=> (!$in_window) ? append_sid($blockgets->root_path . "player.$phpEx", 'id=' . $block_id, false) : '',
	));
	
	if($in_window)
	{
		$template->assign_var('BLOCK_ID', $block_id);
	}

	if(!empty($data['tracks']))
	{
		// prepare the playlist loader class
		$playlist = new playlist();
		$playlist->filter = array('mp3', 'wav');

		foreach($data['tracks'] as $track)
		{
			$track_info = blg_explode_list($track, 2);
			
			/* if is a playlists, load the tracks */
			if(($tracklist = $playlist->load($track_info[1])) !== false)
			{
				foreach($tracklist as $track_info)
				{
					$template->assign_block_vars('track', array(
						'S_TITLE'	=> $track_info['title'],
						'S_URL'		=> $track_info['filename'],
					));
				}
			}
			else
			{
				$template->assign_block_vars('track', array(
					'S_TITLE'	=> $track_info[0],
					'S_URL'		=> $track_info[1],
				));
			}
		}
	}
}

class playlist
{
	var $filter	= false;

	function load($filename)
	{
		$content	= '';
		$ext		= false;

		if(preg_match('#.*\.([a-zA-Z0-9]+)$#', $filename, $match))
		{
			$ext		= $match[1];
			$content	= @file_get_contents($filename);
		}

		if(!$content || !$ext || !method_exists($this, "_read_$ext"))
		{
			return false;
		}
		
		$content = utf8_encode($content);
		
		$tracklist = $this->{"_read_$ext"}($content);
		
		if($this->filter !== false)
		{
			if(!is_array($this->filter))
			{
				$this->filter = array($this->filter);
			}
			
			foreach($tracklist as $id => $track)
			{
				if(!in_array($track['ext'], $this->filter))
				{
					unset($tracklist[$id]);
				}
			}
		}
		
		return $tracklist;
	}
	
	function _read_asx($content)
	{
		$track_ary = array();

		preg_match_all('#<entry><ref href\s?=\s?"(.*)"\s?/></entry>#i', $content, $matches);
		
		foreach($matches[0] as $id => $null)
		{
			if(($track = $this->_parse_track($matches[1][$id])) !== false)
			{
				$track_ary[] = $track;
			}
		}
		
		return $track_ary;
	}
	
	function _read_m3u($content)
	{
		$regexp = "/(.*)[\r\n]*/i";
		$has_ext = false;
		
		$track_ary = array();

		if(strpos($content, '#EXTM3U') !== false)
		{
			$content = trim(str_replace('#EXTM3U', '', $content));
			$regexp = "/#EXTINF:[0-9]+,([^\r\n]+)[\r\n]*(.*)[\r\n]*/i";
			$has_ext = true;
		}
		
		preg_match_all($regexp, $content, $matches);
		
		foreach($matches[0] as $id => $null)
		{
			$title = $url = '';
	
			if($has_ext)
			{
				$title	= $matches[1][$id];
				$url	= $matches[2][$id];
			}
			else
			{
				$url = $matches[1][$id];
			}
			
			if(($track = $this->_parse_track($url, $title)) !== false)
			{
				$track_ary[] = $track;
			}
		}
		
		return $track_ary;
	}
	
	function _read_pls($content)
	{
		$track_ary = $ary = array();
		
		// Get all lines
		preg_match_all('#(file|title)+([0-9]+)=(.*)#i', $content, $matches);
		
		foreach($matches[0] as $id => $null)
		{
			$i		= (int)$matches[2][$id];
			$type	= strtolower($matches[1][$id]);

			if(!is_array($ary[$i]))
			{
				$ary[$i] = array();
			}

			$ary[$i][$type] = $matches[3][$id];
		}
		
		// Parse content to tracklist
		foreach($ary as $i => $data)
		{
			if(empty($data['file']))
			{
				continue;
			}
			
			$title = (isset($data['title']) ? $data['title'] : '');

			if(($track = $this->_parse_track($data['file'], $title)) !== false)
			{
				$track_ary[] = $track;
			}
		}
		
		return $track_ary;
	}
	
	function _parse_track($url, $title = '')
	{
		$ext = '';

		$url = trim(str_replace('\\', '/', $url));
		
		if(preg_match('#/([^/]+)\.([a-zA-Z0-9]+)$#i', $url, $match))
		{
			if(!$title)
			{
				$title = $match[1];
			}

			$ext = $match[2];
		}
		
		if($title && $url && $ext)
		{
			return array(
				'title'		=> $title,
				'filename'	=> $url,
				'ext'		=> $ext,
			);
		}
		
		return false;
	}
}

?>
